import { InjectionToken, Inject, Injectable, Optional, NgModule, SkipSelf, ɵɵdefineInjectable, ɵɵinject } from '@angular/core';
import { __decorate, __metadata, __param, __extends } from 'tslib';
import { HttpClient, HttpHeaders, HttpParams, HttpUrlEncodingCodec } from '@angular/common/http';

var BASE_PATH = new InjectionToken('basePath');
var COLLECTION_FORMATS = {
    'csv': ',',
    'tsv': '   ',
    'ssv': ' ',
    'pipes': '|'
};

var Configuration = /** @class */ (function () {
    function Configuration(configurationParameters) {
        if (configurationParameters === void 0) { configurationParameters = {}; }
        this.apiKeys = configurationParameters.apiKeys;
        this.username = configurationParameters.username;
        this.password = configurationParameters.password;
        this.accessToken = configurationParameters.accessToken;
        this.basePath = configurationParameters.basePath;
        this.withCredentials = configurationParameters.withCredentials;
    }
    /**
     * Select the correct content-type to use for a request.
     * Uses {@link Configuration#isJsonMime} to determine the correct content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param contentTypes - the array of content types that are available for selection
     * @returns the selected content-type or <code>undefined</code> if no selection could be made.
     */
    Configuration.prototype.selectHeaderContentType = function (contentTypes) {
        var _this = this;
        if (contentTypes.length === 0) {
            return undefined;
        }
        var type = contentTypes.find(function (x) { return _this.isJsonMime(x); });
        if (type === undefined) {
            return contentTypes[0];
        }
        return type;
    };
    /**
     * Select the correct accept content-type to use for a request.
     * Uses {@link Configuration#isJsonMime} to determine the correct accept content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param accepts - the array of content types that are available for selection.
     * @returns the selected content-type or <code>undefined</code> if no selection could be made.
     */
    Configuration.prototype.selectHeaderAccept = function (accepts) {
        var _this = this;
        if (accepts.length === 0) {
            return undefined;
        }
        var type = accepts.find(function (x) { return _this.isJsonMime(x); });
        if (type === undefined) {
            return accepts[0];
        }
        return type;
    };
    /**
     * Check if the given MIME is a JSON MIME.
     * JSON MIME examples:
     *   application/json
     *   application/json; charset=UTF8
     *   APPLICATION/JSON
     *   application/vnd.company+json
     * @param mime - MIME (Multipurpose Internet Mail Extensions)
     * @return True if the given MIME is JSON, false otherwise.
     */
    Configuration.prototype.isJsonMime = function (mime) {
        var jsonMime = new RegExp('^(application\/json|[^;/ \t]+\/[^;/ \t]+[+]json)[ \t]*(;.*)?$', 'i');
        return mime !== null && (jsonMime.test(mime) || mime.toLowerCase() === 'application/json-patch+json');
    };
    return Configuration;
}());

var AllowedAttributeValueService = /** @class */ (function () {
    function AllowedAttributeValueService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    AllowedAttributeValueService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    AllowedAttributeValueService.prototype.allowedAttributeValueCreateAllowedAttributeValues = function (allowedAttributeValuesCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (allowedAttributeValuesCreateRequest === null || allowedAttributeValuesCreateRequest === undefined) {
            throw new Error('Required parameter allowedAttributeValuesCreateRequest was null or undefined when calling allowedAttributeValueCreateAllowedAttributeValues.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/allowedAttributeValues", allowedAttributeValuesCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    AllowedAttributeValueService.prototype.allowedAttributeValueDeleteAllowedAttributeValues = function (allowedAttributeValuesDeleteRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (allowedAttributeValuesDeleteRequest === null || allowedAttributeValuesDeleteRequest === undefined) {
            throw new Error('Required parameter allowedAttributeValuesDeleteRequest was null or undefined when calling allowedAttributeValueDeleteAllowedAttributeValues.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/allowedAttributeValues", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    AllowedAttributeValueService.prototype.allowedAttributeValueGetAllowedAttributeValues = function (namespace, attributeValueListName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling allowedAttributeValueGetAllowedAttributeValues.');
        }
        if (attributeValueListName === null || attributeValueListName === undefined) {
            throw new Error('Required parameter attributeValueListName was null or undefined when calling allowedAttributeValueGetAllowedAttributeValues.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/allowedAttributeValues/namespaces/" + encodeURIComponent(String(namespace)) + "/attributeValueListNames/" + encodeURIComponent(String(attributeValueListName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    AllowedAttributeValueService.ɵprov = ɵɵdefineInjectable({ factory: function AllowedAttributeValueService_Factory() { return new AllowedAttributeValueService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: AllowedAttributeValueService, providedIn: "root" });
    AllowedAttributeValueService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], AllowedAttributeValueService);
    return AllowedAttributeValueService;
}());

var ApplicationService = /** @class */ (function () {
    function ApplicationService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    ApplicationService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    ApplicationService.prototype.applicationGetBuildInfo = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/buildInfo", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApplicationService.ɵprov = ɵɵdefineInjectable({ factory: function ApplicationService_Factory() { return new ApplicationService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: ApplicationService, providedIn: "root" });
    ApplicationService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], ApplicationService);
    return ApplicationService;
}());

var AttributeValueListService = /** @class */ (function () {
    function AttributeValueListService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    AttributeValueListService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    AttributeValueListService.prototype.attributeValueListCreateAttributeValueList = function (attributeValueListCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (attributeValueListCreateRequest === null || attributeValueListCreateRequest === undefined) {
            throw new Error('Required parameter attributeValueListCreateRequest was null or undefined when calling attributeValueListCreateAttributeValueList.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/attributeValueLists", attributeValueListCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    AttributeValueListService.prototype.attributeValueListDeleteAttributeValueList = function (namespace, attributeValueListName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling attributeValueListDeleteAttributeValueList.');
        }
        if (attributeValueListName === null || attributeValueListName === undefined) {
            throw new Error('Required parameter attributeValueListName was null or undefined when calling attributeValueListDeleteAttributeValueList.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/attributeValueLists/namespaces/" + encodeURIComponent(String(namespace)) + "/attributeValueListNames/" + encodeURIComponent(String(attributeValueListName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    AttributeValueListService.prototype.attributeValueListGetAttributeValueList = function (namespace, attributeValueListName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling attributeValueListGetAttributeValueList.');
        }
        if (attributeValueListName === null || attributeValueListName === undefined) {
            throw new Error('Required parameter attributeValueListName was null or undefined when calling attributeValueListGetAttributeValueList.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/attributeValueLists/namespaces/" + encodeURIComponent(String(namespace)) + "/attributeValueListNames/" + encodeURIComponent(String(attributeValueListName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    AttributeValueListService.prototype.attributeValueListGetAttributeValueLists = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/attributeValueLists", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    AttributeValueListService.ɵprov = ɵɵdefineInjectable({ factory: function AttributeValueListService_Factory() { return new AttributeValueListService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: AttributeValueListService, providedIn: "root" });
    AttributeValueListService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], AttributeValueListService);
    return AttributeValueListService;
}());

var AvailabilityDayService = /** @class */ (function () {
    function AvailabilityDayService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    AvailabilityDayService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    AvailabilityDayService.prototype.availabilityDayGetAvailabilityDays = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/availabilityDays", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    AvailabilityDayService.ɵprov = ɵɵdefineInjectable({ factory: function AvailabilityDayService_Factory() { return new AvailabilityDayService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: AvailabilityDayService, providedIn: "root" });
    AvailabilityDayService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], AvailabilityDayService);
    return AvailabilityDayService;
}());

/**
* CustomHttpUrlEncodingCodec
* Fix plus sign (+) not encoding, so sent as blank space
* See: https://github.com/angular/angular/issues/11058#issuecomment-247367318
*/
var CustomHttpUrlEncodingCodec = /** @class */ (function (_super) {
    __extends(CustomHttpUrlEncodingCodec, _super);
    function CustomHttpUrlEncodingCodec() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomHttpUrlEncodingCodec.prototype.encodeKey = function (k) {
        k = _super.prototype.encodeKey.call(this, k);
        return k.replace(/\+/gi, '%2B');
    };
    CustomHttpUrlEncodingCodec.prototype.encodeValue = function (v) {
        v = _super.prototype.encodeValue.call(this, v);
        return v.replace(/\+/gi, '%2B');
    };
    return CustomHttpUrlEncodingCodec;
}(HttpUrlEncodingCodec));

var BusinessObjectDataService = /** @class */ (function () {
    function BusinessObjectDataService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectDataService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectDataService.prototype.businessObjectDataCheckBusinessObjectDataAvailability = function (businessObjectDataAvailabilityRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDataAvailabilityRequest === null || businessObjectDataAvailabilityRequest === undefined) {
            throw new Error('Required parameter businessObjectDataAvailabilityRequest was null or undefined when calling businessObjectDataCheckBusinessObjectDataAvailability.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectData/availability", businessObjectDataAvailabilityRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataCheckBusinessObjectDataAvailabilityCollection = function (businessObjectDataAvailabilityCollectionRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDataAvailabilityCollectionRequest === null || businessObjectDataAvailabilityCollectionRequest === undefined) {
            throw new Error('Required parameter businessObjectDataAvailabilityCollectionRequest was null or undefined when calling businessObjectDataCheckBusinessObjectDataAvailabilityCollection.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectData/availabilityCollection", businessObjectDataAvailabilityCollectionRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataCreateBusinessObjectData = function (businessObjectDataCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDataCreateRequest === null || businessObjectDataCreateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataCreateRequest was null or undefined when calling businessObjectDataCreateBusinessObjectData.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectData", businessObjectDataCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataDeleteBusinessObjectData = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, deleteFiles, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataDeleteBusinessObjectData.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataDeleteBusinessObjectData.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataDeleteBusinessObjectData.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataDeleteBusinessObjectData.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataDeleteBusinessObjectData.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataDeleteBusinessObjectData.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataDeleteBusinessObjectData.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (deleteFiles !== undefined && deleteFiles !== null) {
            queryParameters = queryParameters.set('deleteFiles', deleteFiles);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectData/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataDeleteBusinessObjectData1 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, businessObjectDataVersion, deleteFiles, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataDeleteBusinessObjectData1.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataDeleteBusinessObjectData1.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataDeleteBusinessObjectData1.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataDeleteBusinessObjectData1.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataDeleteBusinessObjectData1.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataDeleteBusinessObjectData1.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataDeleteBusinessObjectData1.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataDeleteBusinessObjectData1.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (deleteFiles !== undefined && deleteFiles !== null) {
            queryParameters = queryParameters.set('deleteFiles', deleteFiles);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectData/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataDeleteBusinessObjectData2 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, businessObjectDataVersion, deleteFiles, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataDeleteBusinessObjectData2.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataDeleteBusinessObjectData2.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataDeleteBusinessObjectData2.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataDeleteBusinessObjectData2.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataDeleteBusinessObjectData2.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataDeleteBusinessObjectData2.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataDeleteBusinessObjectData2.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataDeleteBusinessObjectData2.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataDeleteBusinessObjectData2.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (deleteFiles !== undefined && deleteFiles !== null) {
            queryParameters = queryParameters.set('deleteFiles', deleteFiles);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectData/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataDeleteBusinessObjectData3 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, businessObjectDataVersion, deleteFiles, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataDeleteBusinessObjectData3.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataDeleteBusinessObjectData3.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataDeleteBusinessObjectData3.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataDeleteBusinessObjectData3.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataDeleteBusinessObjectData3.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataDeleteBusinessObjectData3.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataDeleteBusinessObjectData3.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataDeleteBusinessObjectData3.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataDeleteBusinessObjectData3.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataDeleteBusinessObjectData3.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (deleteFiles !== undefined && deleteFiles !== null) {
            queryParameters = queryParameters.set('deleteFiles', deleteFiles);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectData/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataDeleteBusinessObjectData4 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, subPartition4Value, businessObjectDataVersion, deleteFiles, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataDeleteBusinessObjectData4.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataDeleteBusinessObjectData4.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataDeleteBusinessObjectData4.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataDeleteBusinessObjectData4.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataDeleteBusinessObjectData4.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataDeleteBusinessObjectData4.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataDeleteBusinessObjectData4.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataDeleteBusinessObjectData4.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataDeleteBusinessObjectData4.');
        }
        if (subPartition4Value === null || subPartition4Value === undefined) {
            throw new Error('Required parameter subPartition4Value was null or undefined when calling businessObjectDataDeleteBusinessObjectData4.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataDeleteBusinessObjectData4.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (deleteFiles !== undefined && deleteFiles !== null) {
            queryParameters = queryParameters.set('deleteFiles', deleteFiles);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectData/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/subPartition4Values/" + encodeURIComponent(String(subPartition4Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataDestroyBusinessObjectData = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, subPartitionValues, batchMode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataDestroyBusinessObjectData.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataDestroyBusinessObjectData.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataDestroyBusinessObjectData.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataDestroyBusinessObjectData.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataDestroyBusinessObjectData.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataDestroyBusinessObjectData.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataDestroyBusinessObjectData.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (subPartitionValues !== undefined && subPartitionValues !== null) {
            queryParameters = queryParameters.set('subPartitionValues', subPartitionValues);
        }
        if (batchMode !== undefined && batchMode !== null) {
            queryParameters = queryParameters.set('batchMode', batchMode);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectData/destroy/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), null, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataDestroyNonRecordBusinessObjectData = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, subPartitionValues, batchMode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataDestroyNonRecordBusinessObjectData.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataDestroyNonRecordBusinessObjectData.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataDestroyNonRecordBusinessObjectData.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataDestroyNonRecordBusinessObjectData.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataDestroyNonRecordBusinessObjectData.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataDestroyNonRecordBusinessObjectData.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataDestroyNonRecordBusinessObjectData.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (subPartitionValues !== undefined && subPartitionValues !== null) {
            queryParameters = queryParameters.set('subPartitionValues', subPartitionValues);
        }
        if (batchMode !== undefined && batchMode !== null) {
            queryParameters = queryParameters.set('batchMode', batchMode);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectData/destroyNonRecord/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), null, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataGenerateBusinessObjectDataDdl = function (businessObjectDataDdlRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDataDdlRequest === null || businessObjectDataDdlRequest === undefined) {
            throw new Error('Required parameter businessObjectDataDdlRequest was null or undefined when calling businessObjectDataGenerateBusinessObjectDataDdl.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectData/generateDdl", businessObjectDataDdlRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataGenerateBusinessObjectDataDdlCollection = function (businessObjectDataDdlCollectionRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDataDdlCollectionRequest === null || businessObjectDataDdlCollectionRequest === undefined) {
            throw new Error('Required parameter businessObjectDataDdlCollectionRequest was null or undefined when calling businessObjectDataGenerateBusinessObjectDataDdlCollection.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectData/generateDdlCollection", businessObjectDataDdlCollectionRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataGenerateBusinessObjectDataPartitions = function (businessObjectDataPartitionsRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDataPartitionsRequest === null || businessObjectDataPartitionsRequest === undefined) {
            throw new Error('Required parameter businessObjectDataPartitionsRequest was null or undefined when calling businessObjectDataGenerateBusinessObjectDataPartitions.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectData/generatePartitions", businessObjectDataPartitionsRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataGetAllBusinessObjectDataByBusinessObjectDefinition = function (namespace, businessObjectDefinitionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataGetAllBusinessObjectDataByBusinessObjectDefinition.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataGetAllBusinessObjectDataByBusinessObjectDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectData/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataGetAllBusinessObjectDataByBusinessObjectDefinitionWithPagination = function (namespace, businessObjectDefinitionName, pageNum, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataGetAllBusinessObjectDataByBusinessObjectDefinitionWithPagination.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataGetAllBusinessObjectDataByBusinessObjectDefinitionWithPagination.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (pageNum !== undefined && pageNum !== null) {
            queryParameters = queryParameters.set('pageNum', pageNum);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectData/all/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataGetAllBusinessObjectDataByBusinessObjectFormat = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataGetAllBusinessObjectDataByBusinessObjectFormat.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataGetAllBusinessObjectDataByBusinessObjectFormat.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataGetAllBusinessObjectDataByBusinessObjectFormat.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataGetAllBusinessObjectDataByBusinessObjectFormat.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataGetAllBusinessObjectDataByBusinessObjectFormat.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectData/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataGetAllBusinessObjectDataByBusinessObjectFormatWithPagination = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, pageNum, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataGetAllBusinessObjectDataByBusinessObjectFormatWithPagination.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataGetAllBusinessObjectDataByBusinessObjectFormatWithPagination.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataGetAllBusinessObjectDataByBusinessObjectFormatWithPagination.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataGetAllBusinessObjectDataByBusinessObjectFormatWithPagination.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataGetAllBusinessObjectDataByBusinessObjectFormatWithPagination.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (pageNum !== undefined && pageNum !== null) {
            queryParameters = queryParameters.set('pageNum', pageNum);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectData/all/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataGetBusinessObjectData = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, partitionKey, partitionValue, subPartitionValues, businessObjectFormatVersion, businessObjectDataVersion, businessObjectDataStatus, includeBusinessObjectDataStatusHistory, includeStorageUnitStatusHistory, excludeBusinessObjectDataStorageFiles, excludeLineageInformation, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataGetBusinessObjectData.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataGetBusinessObjectData.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataGetBusinessObjectData.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataGetBusinessObjectData.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (partitionKey !== undefined && partitionKey !== null) {
            queryParameters = queryParameters.set('partitionKey', partitionKey);
        }
        if (partitionValue !== undefined && partitionValue !== null) {
            queryParameters = queryParameters.set('partitionValue', partitionValue);
        }
        if (subPartitionValues !== undefined && subPartitionValues !== null) {
            queryParameters = queryParameters.set('subPartitionValues', subPartitionValues);
        }
        if (businessObjectFormatVersion !== undefined && businessObjectFormatVersion !== null) {
            queryParameters = queryParameters.set('businessObjectFormatVersion', businessObjectFormatVersion);
        }
        if (businessObjectDataVersion !== undefined && businessObjectDataVersion !== null) {
            queryParameters = queryParameters.set('businessObjectDataVersion', businessObjectDataVersion);
        }
        if (businessObjectDataStatus !== undefined && businessObjectDataStatus !== null) {
            queryParameters = queryParameters.set('businessObjectDataStatus', businessObjectDataStatus);
        }
        if (includeBusinessObjectDataStatusHistory !== undefined && includeBusinessObjectDataStatusHistory !== null) {
            queryParameters = queryParameters.set('includeBusinessObjectDataStatusHistory', includeBusinessObjectDataStatusHistory);
        }
        if (includeStorageUnitStatusHistory !== undefined && includeStorageUnitStatusHistory !== null) {
            queryParameters = queryParameters.set('includeStorageUnitStatusHistory', includeStorageUnitStatusHistory);
        }
        if (excludeBusinessObjectDataStorageFiles !== undefined && excludeBusinessObjectDataStorageFiles !== null) {
            queryParameters = queryParameters.set('excludeBusinessObjectDataStorageFiles', excludeBusinessObjectDataStorageFiles);
        }
        if (excludeLineageInformation !== undefined && excludeLineageInformation !== null) {
            queryParameters = queryParameters.set('excludeLineageInformation', excludeLineageInformation);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectData/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataGetBusinessObjectDataVersions = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, partitionValue, subPartitionValues, businessObjectFormatVersion, businessObjectDataVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataGetBusinessObjectDataVersions.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataGetBusinessObjectDataVersions.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataGetBusinessObjectDataVersions.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataGetBusinessObjectDataVersions.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (partitionValue !== undefined && partitionValue !== null) {
            queryParameters = queryParameters.set('partitionValue', partitionValue);
        }
        if (subPartitionValues !== undefined && subPartitionValues !== null) {
            queryParameters = queryParameters.set('subPartitionValues', subPartitionValues);
        }
        if (businessObjectFormatVersion !== undefined && businessObjectFormatVersion !== null) {
            queryParameters = queryParameters.set('businessObjectFormatVersion', businessObjectFormatVersion);
        }
        if (businessObjectDataVersion !== undefined && businessObjectDataVersion !== null) {
            queryParameters = queryParameters.set('businessObjectDataVersion', businessObjectDataVersion);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectData/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/versions", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataGetS3KeyPrefix = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionKey, partitionValue, subPartitionValues, businessObjectDataVersion, storageName, createNewVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataGetS3KeyPrefix.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataGetS3KeyPrefix.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataGetS3KeyPrefix.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataGetS3KeyPrefix.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataGetS3KeyPrefix.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (partitionKey !== undefined && partitionKey !== null) {
            queryParameters = queryParameters.set('partitionKey', partitionKey);
        }
        if (partitionValue !== undefined && partitionValue !== null) {
            queryParameters = queryParameters.set('partitionValue', partitionValue);
        }
        if (subPartitionValues !== undefined && subPartitionValues !== null) {
            queryParameters = queryParameters.set('subPartitionValues', subPartitionValues);
        }
        if (businessObjectDataVersion !== undefined && businessObjectDataVersion !== null) {
            queryParameters = queryParameters.set('businessObjectDataVersion', businessObjectDataVersion);
        }
        if (storageName !== undefined && storageName !== null) {
            queryParameters = queryParameters.set('storageName', storageName);
        }
        if (createNewVersion !== undefined && createNewVersion !== null) {
            queryParameters = queryParameters.set('createNewVersion', createNewVersion);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectData/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/s3KeyPrefix", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataInvalidateUnregisteredBusinessObjectData = function (businessObjectDataInvalidateUnregisteredRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDataInvalidateUnregisteredRequest === null || businessObjectDataInvalidateUnregisteredRequest === undefined) {
            throw new Error('Required parameter businessObjectDataInvalidateUnregisteredRequest was null or undefined when calling businessObjectDataInvalidateUnregisteredBusinessObjectData.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectData/unregistered/invalidation", businessObjectDataInvalidateUnregisteredRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataRestoreBusinessObjectData = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, subPartitionValues, expirationInDays, archiveRetrievalOption, batchMode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataRestoreBusinessObjectData.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataRestoreBusinessObjectData.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataRestoreBusinessObjectData.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataRestoreBusinessObjectData.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataRestoreBusinessObjectData.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataRestoreBusinessObjectData.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataRestoreBusinessObjectData.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (subPartitionValues !== undefined && subPartitionValues !== null) {
            queryParameters = queryParameters.set('subPartitionValues', subPartitionValues);
        }
        if (expirationInDays !== undefined && expirationInDays !== null) {
            queryParameters = queryParameters.set('expirationInDays', expirationInDays);
        }
        if (archiveRetrievalOption !== undefined && archiveRetrievalOption !== null) {
            queryParameters = queryParameters.set('archiveRetrievalOption', archiveRetrievalOption);
        }
        if (batchMode !== undefined && batchMode !== null) {
            queryParameters = queryParameters.set('batchMode', batchMode);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectData/restore/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), null, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataRetryStoragePolicyTransition = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, businessObjectDataRetryStoragePolicyTransitionRequest, subPartitionValues, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataRetryStoragePolicyTransition.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataRetryStoragePolicyTransition.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataRetryStoragePolicyTransition.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataRetryStoragePolicyTransition.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataRetryStoragePolicyTransition.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataRetryStoragePolicyTransition.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataRetryStoragePolicyTransition.');
        }
        if (businessObjectDataRetryStoragePolicyTransitionRequest === null || businessObjectDataRetryStoragePolicyTransitionRequest === undefined) {
            throw new Error('Required parameter businessObjectDataRetryStoragePolicyTransitionRequest was null or undefined when calling businessObjectDataRetryStoragePolicyTransition.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (subPartitionValues !== undefined && subPartitionValues !== null) {
            queryParameters = queryParameters.set('subPartitionValues', subPartitionValues);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectData/retryStoragePolicyTransition/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), businessObjectDataRetryStoragePolicyTransitionRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataSearchBusinessObjectData = function (businessObjectDataSearchRequest, pageNum, pageSize, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDataSearchRequest === null || businessObjectDataSearchRequest === undefined) {
            throw new Error('Required parameter businessObjectDataSearchRequest was null or undefined when calling businessObjectDataSearchBusinessObjectData.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (pageNum !== undefined && pageNum !== null) {
            queryParameters = queryParameters.set('pageNum', pageNum);
        }
        if (pageSize !== undefined && pageSize !== null) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectData/search", businessObjectDataSearchRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataUpdateBusinessObjectDataAttributes = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, businessObjectDataAttributesUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes.');
        }
        if (businessObjectDataAttributesUpdateRequest === null || businessObjectDataAttributesUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataAttributesUpdateRequest was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), businessObjectDataAttributesUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataUpdateBusinessObjectDataAttributes1 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, businessObjectDataVersion, businessObjectDataAttributesUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes1.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes1.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes1.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes1.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes1.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes1.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes1.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes1.');
        }
        if (businessObjectDataAttributesUpdateRequest === null || businessObjectDataAttributesUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataAttributesUpdateRequest was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes1.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), businessObjectDataAttributesUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataUpdateBusinessObjectDataAttributes2 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, businessObjectDataVersion, businessObjectDataAttributesUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes2.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes2.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes2.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes2.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes2.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes2.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes2.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes2.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes2.');
        }
        if (businessObjectDataAttributesUpdateRequest === null || businessObjectDataAttributesUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataAttributesUpdateRequest was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes2.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), businessObjectDataAttributesUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataUpdateBusinessObjectDataAttributes3 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, businessObjectDataVersion, businessObjectDataAttributesUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes3.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes3.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes3.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes3.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes3.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes3.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes3.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes3.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes3.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes3.');
        }
        if (businessObjectDataAttributesUpdateRequest === null || businessObjectDataAttributesUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataAttributesUpdateRequest was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes3.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), businessObjectDataAttributesUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataUpdateBusinessObjectDataAttributes4 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, subPartition4Value, businessObjectDataVersion, businessObjectDataAttributesUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes4.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes4.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes4.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes4.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes4.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes4.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes4.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes4.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes4.');
        }
        if (subPartition4Value === null || subPartition4Value === undefined) {
            throw new Error('Required parameter subPartition4Value was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes4.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes4.');
        }
        if (businessObjectDataAttributesUpdateRequest === null || businessObjectDataAttributesUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataAttributesUpdateRequest was null or undefined when calling businessObjectDataUpdateBusinessObjectDataAttributes4.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/subPartition4Values/" + encodeURIComponent(String(subPartition4Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), businessObjectDataAttributesUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataUpdateBusinessObjectDataLegalHold = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, businessObjectDataLegalHoldUpdateRequest, subPartitionValues, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataUpdateBusinessObjectDataLegalHold.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataUpdateBusinessObjectDataLegalHold.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataUpdateBusinessObjectDataLegalHold.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataUpdateBusinessObjectDataLegalHold.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataLegalHold.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataUpdateBusinessObjectDataLegalHold.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataLegalHold.');
        }
        if (businessObjectDataLegalHoldUpdateRequest === null || businessObjectDataLegalHoldUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataLegalHoldUpdateRequest was null or undefined when calling businessObjectDataUpdateBusinessObjectDataLegalHold.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (subPartitionValues !== undefined && subPartitionValues !== null) {
            queryParameters = queryParameters.set('subPartitionValues', subPartitionValues);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataLegalHold/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), businessObjectDataLegalHoldUpdateRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataUpdateBusinessObjectDataParents = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, businessObjectDataParentsUpdateRequest, subPartitionValues, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataUpdateBusinessObjectDataParents.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataUpdateBusinessObjectDataParents.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataUpdateBusinessObjectDataParents.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataUpdateBusinessObjectDataParents.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataParents.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataUpdateBusinessObjectDataParents.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataParents.');
        }
        if (businessObjectDataParentsUpdateRequest === null || businessObjectDataParentsUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataParentsUpdateRequest was null or undefined when calling businessObjectDataUpdateBusinessObjectDataParents.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (subPartitionValues !== undefined && subPartitionValues !== null) {
            queryParameters = queryParameters.set('subPartitionValues', subPartitionValues);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataParents/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), businessObjectDataParentsUpdateRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.prototype.businessObjectDataUpdateBusinessObjectDataRetentionInformation = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, businessObjectDataRetentionInformationUpdateRequest, subPartitionValues, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataUpdateBusinessObjectDataRetentionInformation.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataUpdateBusinessObjectDataRetentionInformation.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataUpdateBusinessObjectDataRetentionInformation.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataUpdateBusinessObjectDataRetentionInformation.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataRetentionInformation.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataUpdateBusinessObjectDataRetentionInformation.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataUpdateBusinessObjectDataRetentionInformation.');
        }
        if (businessObjectDataRetentionInformationUpdateRequest === null || businessObjectDataRetentionInformationUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataRetentionInformationUpdateRequest was null or undefined when calling businessObjectDataUpdateBusinessObjectDataRetentionInformation.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (subPartitionValues !== undefined && subPartitionValues !== null) {
            queryParameters = queryParameters.set('subPartitionValues', subPartitionValues);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataRetentionInformation/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), businessObjectDataRetentionInformationUpdateRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectDataService_Factory() { return new BusinessObjectDataService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectDataService, providedIn: "root" });
    BusinessObjectDataService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectDataService);
    return BusinessObjectDataService;
}());

var BusinessObjectDataAttributeService = /** @class */ (function () {
    function BusinessObjectDataAttributeService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectDataAttributeService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeCreateBusinessObjectDataAttribute = function (businessObjectDataAttributeCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDataAttributeCreateRequest === null || businessObjectDataAttributeCreateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeCreateRequest was null or undefined when calling businessObjectDataAttributeCreateBusinessObjectDataAttribute.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectDataAttributes", businessObjectDataAttributeCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeDeleteBusinessObjectDataAttribute = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, businessObjectDataAttributeName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeDeleteBusinessObjectDataAttribute1 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, businessObjectDataVersion, businessObjectDataAttributeName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute1.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute1.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute1.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute1.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute1.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute1.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute1.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute1.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute1.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeDeleteBusinessObjectDataAttribute2 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, businessObjectDataVersion, businessObjectDataAttributeName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute2.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute2.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute2.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute2.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute2.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute2.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute2.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute2.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute2.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute2.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeDeleteBusinessObjectDataAttribute3 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, businessObjectDataVersion, businessObjectDataAttributeName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute3.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute3.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute3.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute3.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute3.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute3.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute3.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute3.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute3.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute3.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute3.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeDeleteBusinessObjectDataAttribute4 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, subPartition4Value, businessObjectDataVersion, businessObjectDataAttributeName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute4.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute4.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute4.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute4.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute4.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute4.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute4.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute4.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute4.');
        }
        if (subPartition4Value === null || subPartition4Value === undefined) {
            throw new Error('Required parameter subPartition4Value was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute4.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute4.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeDeleteBusinessObjectDataAttribute4.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/subPartition4Values/" + encodeURIComponent(String(subPartition4Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeGetBusinessObjectDataAttribute = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, businessObjectDataAttributeName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeGetBusinessObjectDataAttribute1 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, businessObjectDataVersion, businessObjectDataAttributeName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute1.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute1.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute1.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute1.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute1.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute1.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute1.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute1.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute1.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeGetBusinessObjectDataAttribute2 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, businessObjectDataVersion, businessObjectDataAttributeName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute2.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute2.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute2.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute2.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute2.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute2.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute2.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute2.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute2.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute2.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeGetBusinessObjectDataAttribute3 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, businessObjectDataVersion, businessObjectDataAttributeName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute3.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute3.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute3.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute3.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute3.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute3.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute3.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute3.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute3.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute3.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute3.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeGetBusinessObjectDataAttribute4 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, subPartition4Value, businessObjectDataVersion, businessObjectDataAttributeName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute4.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute4.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute4.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute4.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute4.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute4.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute4.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute4.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute4.');
        }
        if (subPartition4Value === null || subPartition4Value === undefined) {
            throw new Error('Required parameter subPartition4Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute4.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute4.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttribute4.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/subPartition4Values/" + encodeURIComponent(String(subPartition4Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeGetBusinessObjectDataAttributes = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeGetBusinessObjectDataAttributes1 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, businessObjectDataVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes1.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes1.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes1.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes1.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes1.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes1.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes1.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes1.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeGetBusinessObjectDataAttributes2 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, businessObjectDataVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes2.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes2.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes2.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes2.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes2.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes2.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes2.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes2.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes2.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeGetBusinessObjectDataAttributes3 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, businessObjectDataVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes3.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes3.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes3.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes3.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes3.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes3.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes3.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes3.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes3.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes3.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeGetBusinessObjectDataAttributes4 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, subPartition4Value, businessObjectDataVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes4.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes4.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes4.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes4.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes4.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes4.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes4.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes4.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes4.');
        }
        if (subPartition4Value === null || subPartition4Value === undefined) {
            throw new Error('Required parameter subPartition4Value was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes4.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeGetBusinessObjectDataAttributes4.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/subPartition4Values/" + encodeURIComponent(String(subPartition4Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeUpdateBusinessObjectDataAttribute = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, businessObjectDataAttributeName, businessObjectDataAttributeUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute.');
        }
        if (businessObjectDataAttributeUpdateRequest === null || businessObjectDataAttributeUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeUpdateRequest was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), businessObjectDataAttributeUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeUpdateBusinessObjectDataAttribute1 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, businessObjectDataVersion, businessObjectDataAttributeName, businessObjectDataAttributeUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute1.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute1.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute1.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute1.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute1.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute1.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute1.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute1.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute1.');
        }
        if (businessObjectDataAttributeUpdateRequest === null || businessObjectDataAttributeUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeUpdateRequest was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute1.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), businessObjectDataAttributeUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeUpdateBusinessObjectDataAttribute2 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, businessObjectDataVersion, businessObjectDataAttributeName, businessObjectDataAttributeUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute2.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute2.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute2.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute2.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute2.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute2.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute2.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute2.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute2.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute2.');
        }
        if (businessObjectDataAttributeUpdateRequest === null || businessObjectDataAttributeUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeUpdateRequest was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute2.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), businessObjectDataAttributeUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeUpdateBusinessObjectDataAttribute3 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, businessObjectDataVersion, businessObjectDataAttributeName, businessObjectDataAttributeUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute3.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute3.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute3.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute3.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute3.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute3.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute3.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute3.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute3.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute3.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute3.');
        }
        if (businessObjectDataAttributeUpdateRequest === null || businessObjectDataAttributeUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeUpdateRequest was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute3.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), businessObjectDataAttributeUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.prototype.businessObjectDataAttributeUpdateBusinessObjectDataAttribute4 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, subPartition4Value, businessObjectDataVersion, businessObjectDataAttributeName, businessObjectDataAttributeUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute4.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute4.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute4.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute4.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute4.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute4.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute4.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute4.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute4.');
        }
        if (subPartition4Value === null || subPartition4Value === undefined) {
            throw new Error('Required parameter subPartition4Value was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute4.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute4.');
        }
        if (businessObjectDataAttributeName === null || businessObjectDataAttributeName === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeName was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute4.');
        }
        if (businessObjectDataAttributeUpdateRequest === null || businessObjectDataAttributeUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataAttributeUpdateRequest was null or undefined when calling businessObjectDataAttributeUpdateBusinessObjectDataAttribute4.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/subPartition4Values/" + encodeURIComponent(String(subPartition4Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/businessObjectDataAttributeNames/" + encodeURIComponent(String(businessObjectDataAttributeName)), businessObjectDataAttributeUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataAttributeService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectDataAttributeService_Factory() { return new BusinessObjectDataAttributeService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectDataAttributeService, providedIn: "root" });
    BusinessObjectDataAttributeService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectDataAttributeService);
    return BusinessObjectDataAttributeService;
}());

var BusinessObjectDataNotificationRegistrationService = /** @class */ (function () {
    function BusinessObjectDataNotificationRegistrationService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectDataNotificationRegistrationService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectDataNotificationRegistrationService.prototype.businessObjectDataNotificationRegistrationCreateBusinessObjectDataNotificationRegistration = function (businessObjectDataNotificationRegistrationCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDataNotificationRegistrationCreateRequest === null || businessObjectDataNotificationRegistrationCreateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataNotificationRegistrationCreateRequest was null or undefined when calling businessObjectDataNotificationRegistrationCreateBusinessObjectDataNotificationRegistration.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/notificationRegistrations/businessObjectDataNotificationRegistrations", businessObjectDataNotificationRegistrationCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataNotificationRegistrationService.prototype.businessObjectDataNotificationRegistrationDeleteBusinessObjectDataNotification = function (namespace, notificationName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataNotificationRegistrationDeleteBusinessObjectDataNotification.');
        }
        if (notificationName === null || notificationName === undefined) {
            throw new Error('Required parameter notificationName was null or undefined when calling businessObjectDataNotificationRegistrationDeleteBusinessObjectDataNotification.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/notificationRegistrations/businessObjectDataNotificationRegistrations/namespaces/" + encodeURIComponent(String(namespace)) + "/notificationNames/" + encodeURIComponent(String(notificationName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataNotificationRegistrationService.prototype.businessObjectDataNotificationRegistrationGetBusinessObjectDataNotificationRegistration = function (namespace, notificationName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataNotificationRegistrationGetBusinessObjectDataNotificationRegistration.');
        }
        if (notificationName === null || notificationName === undefined) {
            throw new Error('Required parameter notificationName was null or undefined when calling businessObjectDataNotificationRegistrationGetBusinessObjectDataNotificationRegistration.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/notificationRegistrations/businessObjectDataNotificationRegistrations/namespaces/" + encodeURIComponent(String(namespace)) + "/notificationNames/" + encodeURIComponent(String(notificationName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataNotificationRegistrationService.prototype.businessObjectDataNotificationRegistrationGetBusinessObjectDataNotificationRegistrationsByNamespace = function (namespace, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataNotificationRegistrationGetBusinessObjectDataNotificationRegistrationsByNamespace.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/notificationRegistrations/businessObjectDataNotificationRegistrations/namespaces/" + encodeURIComponent(String(namespace)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataNotificationRegistrationService.prototype.businessObjectDataNotificationRegistrationGetBusinessObjectDataNotificationRegistrationsByNotificationFilter = function (businessObjectDefinitionNamespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDefinitionNamespace === null || businessObjectDefinitionNamespace === undefined) {
            throw new Error('Required parameter businessObjectDefinitionNamespace was null or undefined when calling businessObjectDataNotificationRegistrationGetBusinessObjectDataNotificationRegistrationsByNotificationFilter.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataNotificationRegistrationGetBusinessObjectDataNotificationRegistrationsByNotificationFilter.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (businessObjectDefinitionNamespace !== undefined && businessObjectDefinitionNamespace !== null) {
            queryParameters = queryParameters.set('businessObjectDefinitionNamespace', businessObjectDefinitionNamespace);
        }
        if (businessObjectDefinitionName !== undefined && businessObjectDefinitionName !== null) {
            queryParameters = queryParameters.set('businessObjectDefinitionName', businessObjectDefinitionName);
        }
        if (businessObjectFormatUsage !== undefined && businessObjectFormatUsage !== null) {
            queryParameters = queryParameters.set('businessObjectFormatUsage', businessObjectFormatUsage);
        }
        if (businessObjectFormatFileType !== undefined && businessObjectFormatFileType !== null) {
            queryParameters = queryParameters.set('businessObjectFormatFileType', businessObjectFormatFileType);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/notificationRegistrations/businessObjectDataNotificationRegistrations", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataNotificationRegistrationService.prototype.businessObjectDataNotificationRegistrationSearchBusinessObjectDataNotificationRegistrations = function (businessObjectDataNotificationRegistrationSearchRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDataNotificationRegistrationSearchRequest === null || businessObjectDataNotificationRegistrationSearchRequest === undefined) {
            throw new Error('Required parameter businessObjectDataNotificationRegistrationSearchRequest was null or undefined when calling businessObjectDataNotificationRegistrationSearchBusinessObjectDataNotificationRegistrations.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/notificationRegistrations/businessObjectDataNotificationRegistrations/search", businessObjectDataNotificationRegistrationSearchRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataNotificationRegistrationService.prototype.businessObjectDataNotificationRegistrationUpdateBusinessObjectDataNotificationRegistration = function (namespace, notificationName, businessObjectDataNotificationRegistrationUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataNotificationRegistrationUpdateBusinessObjectDataNotificationRegistration.');
        }
        if (notificationName === null || notificationName === undefined) {
            throw new Error('Required parameter notificationName was null or undefined when calling businessObjectDataNotificationRegistrationUpdateBusinessObjectDataNotificationRegistration.');
        }
        if (businessObjectDataNotificationRegistrationUpdateRequest === null || businessObjectDataNotificationRegistrationUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataNotificationRegistrationUpdateRequest was null or undefined when calling businessObjectDataNotificationRegistrationUpdateBusinessObjectDataNotificationRegistration.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/notificationRegistrations/businessObjectDataNotificationRegistrations/namespaces/" + encodeURIComponent(String(namespace)) + "/notificationNames/" + encodeURIComponent(String(notificationName)), businessObjectDataNotificationRegistrationUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataNotificationRegistrationService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectDataNotificationRegistrationService_Factory() { return new BusinessObjectDataNotificationRegistrationService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectDataNotificationRegistrationService, providedIn: "root" });
    BusinessObjectDataNotificationRegistrationService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectDataNotificationRegistrationService);
    return BusinessObjectDataNotificationRegistrationService;
}());

var BusinessObjectDataStatusService = /** @class */ (function () {
    function BusinessObjectDataStatusService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectDataStatusService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectDataStatusService.prototype.businessObjectDataStatusGetBusinessObjectDataStatus = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, partitionKey, partitionValue, subPartitionValues, businessObjectFormatVersion, businessObjectDataVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataStatusGetBusinessObjectDataStatus.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataStatusGetBusinessObjectDataStatus.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataStatusGetBusinessObjectDataStatus.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataStatusGetBusinessObjectDataStatus.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (partitionKey !== undefined && partitionKey !== null) {
            queryParameters = queryParameters.set('partitionKey', partitionKey);
        }
        if (partitionValue !== undefined && partitionValue !== null) {
            queryParameters = queryParameters.set('partitionValue', partitionValue);
        }
        if (subPartitionValues !== undefined && subPartitionValues !== null) {
            queryParameters = queryParameters.set('subPartitionValues', subPartitionValues);
        }
        if (businessObjectFormatVersion !== undefined && businessObjectFormatVersion !== null) {
            queryParameters = queryParameters.set('businessObjectFormatVersion', businessObjectFormatVersion);
        }
        if (businessObjectDataVersion !== undefined && businessObjectDataVersion !== null) {
            queryParameters = queryParameters.set('businessObjectDataVersion', businessObjectDataVersion);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDataStatus/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataStatusService.prototype.businessObjectDataStatusUpdateBusinessObjectDataStatus = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, businessObjectDataStatusUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus.');
        }
        if (businessObjectDataStatusUpdateRequest === null || businessObjectDataStatusUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataStatusUpdateRequest was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataStatus/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), businessObjectDataStatusUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataStatusService.prototype.businessObjectDataStatusUpdateBusinessObjectDataStatus1 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, businessObjectDataVersion, businessObjectDataStatusUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus1.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus1.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus1.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus1.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus1.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus1.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus1.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus1.');
        }
        if (businessObjectDataStatusUpdateRequest === null || businessObjectDataStatusUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataStatusUpdateRequest was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus1.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataStatus/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), businessObjectDataStatusUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataStatusService.prototype.businessObjectDataStatusUpdateBusinessObjectDataStatus2 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, businessObjectDataVersion, businessObjectDataStatusUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus2.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus2.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus2.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus2.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus2.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus2.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus2.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus2.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus2.');
        }
        if (businessObjectDataStatusUpdateRequest === null || businessObjectDataStatusUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataStatusUpdateRequest was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus2.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataStatus/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), businessObjectDataStatusUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataStatusService.prototype.businessObjectDataStatusUpdateBusinessObjectDataStatus3 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, businessObjectDataVersion, businessObjectDataStatusUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus3.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus3.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus3.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus3.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus3.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus3.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus3.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus3.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus3.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus3.');
        }
        if (businessObjectDataStatusUpdateRequest === null || businessObjectDataStatusUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataStatusUpdateRequest was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus3.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataStatus/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), businessObjectDataStatusUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataStatusService.prototype.businessObjectDataStatusUpdateBusinessObjectDataStatus4 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, subPartition4Value, businessObjectDataVersion, businessObjectDataStatusUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus4.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus4.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus4.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus4.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus4.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus4.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus4.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus4.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus4.');
        }
        if (subPartition4Value === null || subPartition4Value === undefined) {
            throw new Error('Required parameter subPartition4Value was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus4.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus4.');
        }
        if (businessObjectDataStatusUpdateRequest === null || businessObjectDataStatusUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataStatusUpdateRequest was null or undefined when calling businessObjectDataStatusUpdateBusinessObjectDataStatus4.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataStatus/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/subPartition4Values/" + encodeURIComponent(String(subPartition4Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), businessObjectDataStatusUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataStatusService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectDataStatusService_Factory() { return new BusinessObjectDataStatusService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectDataStatusService, providedIn: "root" });
    BusinessObjectDataStatusService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectDataStatusService);
    return BusinessObjectDataStatusService;
}());

var BusinessObjectDataStorageFileService = /** @class */ (function () {
    function BusinessObjectDataStorageFileService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectDataStorageFileService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectDataStorageFileService.prototype.businessObjectDataStorageFileCreateBusinessObjectDataStorageFiles = function (businessObjectDataStorageFilesCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDataStorageFilesCreateRequest === null || businessObjectDataStorageFilesCreateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataStorageFilesCreateRequest was null or undefined when calling businessObjectDataStorageFileCreateBusinessObjectDataStorageFiles.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectDataStorageFiles", businessObjectDataStorageFilesCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataStorageFileService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectDataStorageFileService_Factory() { return new BusinessObjectDataStorageFileService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectDataStorageFileService, providedIn: "root" });
    BusinessObjectDataStorageFileService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectDataStorageFileService);
    return BusinessObjectDataStorageFileService;
}());

var BusinessObjectDataStorageUnitService = /** @class */ (function () {
    function BusinessObjectDataStorageUnitService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectDataStorageUnitService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectDataStorageUnitService.prototype.businessObjectDataStorageUnitCreateBusinessObjectDataStorageUnit = function (businessObjectDataStorageUnitCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDataStorageUnitCreateRequest === null || businessObjectDataStorageUnitCreateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataStorageUnitCreateRequest was null or undefined when calling businessObjectDataStorageUnitCreateBusinessObjectDataStorageUnit.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectDataStorageUnits", businessObjectDataStorageUnitCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataStorageUnitService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectDataStorageUnitService_Factory() { return new BusinessObjectDataStorageUnitService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectDataStorageUnitService, providedIn: "root" });
    BusinessObjectDataStorageUnitService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectDataStorageUnitService);
    return BusinessObjectDataStorageUnitService;
}());

var BusinessObjectDataStorageUnitStatusService = /** @class */ (function () {
    function BusinessObjectDataStorageUnitStatusService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectDataStorageUnitStatusService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectDataStorageUnitStatusService.prototype.businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, storageName, businessObjectDataStorageUnitStatusUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus.');
        }
        if (storageName === null || storageName === undefined) {
            throw new Error('Required parameter storageName was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus.');
        }
        if (businessObjectDataStorageUnitStatusUpdateRequest === null || businessObjectDataStorageUnitStatusUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataStorageUnitStatusUpdateRequest was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataStorageUnitStatus/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/storageNames/" + encodeURIComponent(String(storageName)), businessObjectDataStorageUnitStatusUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataStorageUnitStatusService.prototype.businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus1 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, businessObjectDataVersion, storageName, businessObjectDataStorageUnitStatusUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus1.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus1.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus1.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus1.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus1.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus1.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus1.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus1.');
        }
        if (storageName === null || storageName === undefined) {
            throw new Error('Required parameter storageName was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus1.');
        }
        if (businessObjectDataStorageUnitStatusUpdateRequest === null || businessObjectDataStorageUnitStatusUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataStorageUnitStatusUpdateRequest was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus1.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataStorageUnitStatus/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/storageNames/" + encodeURIComponent(String(storageName)), businessObjectDataStorageUnitStatusUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataStorageUnitStatusService.prototype.businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus2 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, businessObjectDataVersion, storageName, businessObjectDataStorageUnitStatusUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus2.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus2.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus2.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus2.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus2.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus2.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus2.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus2.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus2.');
        }
        if (storageName === null || storageName === undefined) {
            throw new Error('Required parameter storageName was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus2.');
        }
        if (businessObjectDataStorageUnitStatusUpdateRequest === null || businessObjectDataStorageUnitStatusUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataStorageUnitStatusUpdateRequest was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus2.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataStorageUnitStatus/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/storageNames/" + encodeURIComponent(String(storageName)), businessObjectDataStorageUnitStatusUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataStorageUnitStatusService.prototype.businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus3 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, businessObjectDataVersion, storageName, businessObjectDataStorageUnitStatusUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus3.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus3.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus3.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus3.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus3.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus3.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus3.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus3.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus3.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus3.');
        }
        if (storageName === null || storageName === undefined) {
            throw new Error('Required parameter storageName was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus3.');
        }
        if (businessObjectDataStorageUnitStatusUpdateRequest === null || businessObjectDataStorageUnitStatusUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataStorageUnitStatusUpdateRequest was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus3.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataStorageUnitStatus/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/storageNames/" + encodeURIComponent(String(storageName)), businessObjectDataStorageUnitStatusUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataStorageUnitStatusService.prototype.businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus4 = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, subPartition1Value, subPartition2Value, subPartition3Value, subPartition4Value, businessObjectDataVersion, storageName, businessObjectDataStorageUnitStatusUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus4.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus4.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus4.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus4.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus4.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus4.');
        }
        if (subPartition1Value === null || subPartition1Value === undefined) {
            throw new Error('Required parameter subPartition1Value was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus4.');
        }
        if (subPartition2Value === null || subPartition2Value === undefined) {
            throw new Error('Required parameter subPartition2Value was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus4.');
        }
        if (subPartition3Value === null || subPartition3Value === undefined) {
            throw new Error('Required parameter subPartition3Value was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus4.');
        }
        if (subPartition4Value === null || subPartition4Value === undefined) {
            throw new Error('Required parameter subPartition4Value was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus4.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus4.');
        }
        if (storageName === null || storageName === undefined) {
            throw new Error('Required parameter storageName was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus4.');
        }
        if (businessObjectDataStorageUnitStatusUpdateRequest === null || businessObjectDataStorageUnitStatusUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDataStorageUnitStatusUpdateRequest was null or undefined when calling businessObjectDataStorageUnitStatusUpdateBusinessObjectDataStorageUnitStatus4.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDataStorageUnitStatus/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/subPartition1Values/" + encodeURIComponent(String(subPartition1Value)) + "/subPartition2Values/" + encodeURIComponent(String(subPartition2Value)) + "/subPartition3Values/" + encodeURIComponent(String(subPartition3Value)) + "/subPartition4Values/" + encodeURIComponent(String(subPartition4Value)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/storageNames/" + encodeURIComponent(String(storageName)), businessObjectDataStorageUnitStatusUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDataStorageUnitStatusService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectDataStorageUnitStatusService_Factory() { return new BusinessObjectDataStorageUnitStatusService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectDataStorageUnitStatusService, providedIn: "root" });
    BusinessObjectDataStorageUnitStatusService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectDataStorageUnitStatusService);
    return BusinessObjectDataStorageUnitStatusService;
}());

var BusinessObjectDefinitionService = /** @class */ (function () {
    function BusinessObjectDefinitionService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectDefinitionService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectDefinitionService.prototype.businessObjectDefinitionCreateBusinessObjectDefinition = function (businessObjectDefinitionCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDefinitionCreateRequest === null || businessObjectDefinitionCreateRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionCreateRequest was null or undefined when calling businessObjectDefinitionCreateBusinessObjectDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectDefinitions", businessObjectDefinitionCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionService.prototype.businessObjectDefinitionDeleteBusinessObjectDefinition = function (namespace, businessObjectDefinitionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionDeleteBusinessObjectDefinition.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionDeleteBusinessObjectDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectDefinitions/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionService.prototype.businessObjectDefinitionGetBusinessObjectDefinition = function (namespace, businessObjectDefinitionName, includeBusinessObjectDefinitionUpdateHistory, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionGetBusinessObjectDefinition.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionGetBusinessObjectDefinition.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (includeBusinessObjectDefinitionUpdateHistory !== undefined && includeBusinessObjectDefinitionUpdateHistory !== null) {
            queryParameters = queryParameters.set('includeBusinessObjectDefinitionUpdateHistory', includeBusinessObjectDefinitionUpdateHistory);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDefinitions/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionService.prototype.businessObjectDefinitionGetBusinessObjectDefinitions = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDefinitions", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionService.prototype.businessObjectDefinitionGetBusinessObjectDefinitions1 = function (namespace, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionGetBusinessObjectDefinitions1.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDefinitions/namespaces/" + encodeURIComponent(String(namespace)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionService.prototype.businessObjectDefinitionSearchBusinessObjectDefinitions = function (businessObjectDefinitionSearchRequest, fields, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDefinitionSearchRequest === null || businessObjectDefinitionSearchRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionSearchRequest was null or undefined when calling businessObjectDefinitionSearchBusinessObjectDefinitions.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (fields !== undefined && fields !== null) {
            queryParameters = queryParameters.set('fields', fields);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectDefinitions/search", businessObjectDefinitionSearchRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionService.prototype.businessObjectDefinitionUpdateBusinessObjectDefinition = function (namespace, businessObjectDefinitionName, businessObjectDefinitionUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionUpdateBusinessObjectDefinition.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionUpdateBusinessObjectDefinition.');
        }
        if (businessObjectDefinitionUpdateRequest === null || businessObjectDefinitionUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionUpdateRequest was null or undefined when calling businessObjectDefinitionUpdateBusinessObjectDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDefinitions/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)), businessObjectDefinitionUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionService.prototype.businessObjectDefinitionUpdateBusinessObjectDefinitionAttributes = function (namespace, businessObjectDefinitionName, businessObjectDefinitionAttributesUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionUpdateBusinessObjectDefinitionAttributes.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionUpdateBusinessObjectDefinitionAttributes.');
        }
        if (businessObjectDefinitionAttributesUpdateRequest === null || businessObjectDefinitionAttributesUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionAttributesUpdateRequest was null or undefined when calling businessObjectDefinitionUpdateBusinessObjectDefinitionAttributes.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDefinitionAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)), businessObjectDefinitionAttributesUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionService.prototype.businessObjectDefinitionUpdateBusinessObjectDefinitionDepartment = function (namespace, businessObjectDefinitionName, businessObjectDefinitionDepartmentUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionUpdateBusinessObjectDefinitionDepartment.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionUpdateBusinessObjectDefinitionDepartment.');
        }
        if (businessObjectDefinitionDepartmentUpdateRequest === null || businessObjectDefinitionDepartmentUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionDepartmentUpdateRequest was null or undefined when calling businessObjectDefinitionUpdateBusinessObjectDefinitionDepartment.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDefinitionDepartment/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)), businessObjectDefinitionDepartmentUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionService.prototype.businessObjectDefinitionUpdateBusinessObjectDefinitionDescriptiveInformation = function (namespace, businessObjectDefinitionName, businessObjectDefinitionDescriptiveInformationUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionUpdateBusinessObjectDefinitionDescriptiveInformation.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionUpdateBusinessObjectDefinitionDescriptiveInformation.');
        }
        if (businessObjectDefinitionDescriptiveInformationUpdateRequest === null || businessObjectDefinitionDescriptiveInformationUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionDescriptiveInformationUpdateRequest was null or undefined when calling businessObjectDefinitionUpdateBusinessObjectDefinitionDescriptiveInformation.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDefinitionDescriptiveInformation/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)), businessObjectDefinitionDescriptiveInformationUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectDefinitionService_Factory() { return new BusinessObjectDefinitionService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectDefinitionService, providedIn: "root" });
    BusinessObjectDefinitionService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectDefinitionService);
    return BusinessObjectDefinitionService;
}());

var BusinessObjectDefinitionColumnService = /** @class */ (function () {
    function BusinessObjectDefinitionColumnService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectDefinitionColumnService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectDefinitionColumnService.prototype.businessObjectDefinitionColumnCreateBusinessObjectDefinitionColumn = function (businessObjectDefinitionColumnCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDefinitionColumnCreateRequest === null || businessObjectDefinitionColumnCreateRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionColumnCreateRequest was null or undefined when calling businessObjectDefinitionColumnCreateBusinessObjectDefinitionColumn.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectDefinitionColumns", businessObjectDefinitionColumnCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionColumnService.prototype.businessObjectDefinitionColumnDeleteBusinessObjectDefinitionColumn = function (namespace, businessObjectDefinitionName, businessObjectDefinitionColumnName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionColumnDeleteBusinessObjectDefinitionColumn.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionColumnDeleteBusinessObjectDefinitionColumn.');
        }
        if (businessObjectDefinitionColumnName === null || businessObjectDefinitionColumnName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionColumnName was null or undefined when calling businessObjectDefinitionColumnDeleteBusinessObjectDefinitionColumn.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectDefinitionColumns/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectDefinitionColumnNames/" + encodeURIComponent(String(businessObjectDefinitionColumnName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionColumnService.prototype.businessObjectDefinitionColumnGetBusinessObjectDefinitionColumn = function (namespace, businessObjectDefinitionName, businessObjectDefinitionColumnName, includeBusinessObjectDefinitionColumnUpdateHistory, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionColumnGetBusinessObjectDefinitionColumn.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionColumnGetBusinessObjectDefinitionColumn.');
        }
        if (businessObjectDefinitionColumnName === null || businessObjectDefinitionColumnName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionColumnName was null or undefined when calling businessObjectDefinitionColumnGetBusinessObjectDefinitionColumn.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (includeBusinessObjectDefinitionColumnUpdateHistory !== undefined && includeBusinessObjectDefinitionColumnUpdateHistory !== null) {
            queryParameters = queryParameters.set('includeBusinessObjectDefinitionColumnUpdateHistory', includeBusinessObjectDefinitionColumnUpdateHistory);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDefinitionColumns/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectDefinitionColumnNames/" + encodeURIComponent(String(businessObjectDefinitionColumnName)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionColumnService.prototype.businessObjectDefinitionColumnGetBusinessObjectDefinitionColumns = function (namespace, businessObjectDefinitionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionColumnGetBusinessObjectDefinitionColumns.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionColumnGetBusinessObjectDefinitionColumns.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDefinitionColumns/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionColumnService.prototype.businessObjectDefinitionColumnSearchBusinessObjectDefinitionColumns = function (businessObjectDefinitionColumnSearchRequest, fields, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDefinitionColumnSearchRequest === null || businessObjectDefinitionColumnSearchRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionColumnSearchRequest was null or undefined when calling businessObjectDefinitionColumnSearchBusinessObjectDefinitionColumns.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (fields !== undefined && fields !== null) {
            queryParameters = queryParameters.set('fields', fields);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectDefinitionColumns/search", businessObjectDefinitionColumnSearchRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionColumnService.prototype.businessObjectDefinitionColumnUpdateBusinessObjectDefinitionColumn = function (namespace, businessObjectDefinitionName, businessObjectDefinitionColumnName, businessObjectDefinitionColumnUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionColumnUpdateBusinessObjectDefinitionColumn.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionColumnUpdateBusinessObjectDefinitionColumn.');
        }
        if (businessObjectDefinitionColumnName === null || businessObjectDefinitionColumnName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionColumnName was null or undefined when calling businessObjectDefinitionColumnUpdateBusinessObjectDefinitionColumn.');
        }
        if (businessObjectDefinitionColumnUpdateRequest === null || businessObjectDefinitionColumnUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionColumnUpdateRequest was null or undefined when calling businessObjectDefinitionColumnUpdateBusinessObjectDefinitionColumn.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDefinitionColumns/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectDefinitionColumnNames/" + encodeURIComponent(String(businessObjectDefinitionColumnName)), businessObjectDefinitionColumnUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionColumnService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectDefinitionColumnService_Factory() { return new BusinessObjectDefinitionColumnService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectDefinitionColumnService, providedIn: "root" });
    BusinessObjectDefinitionColumnService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectDefinitionColumnService);
    return BusinessObjectDefinitionColumnService;
}());

var BusinessObjectDefinitionDescriptionSuggestionService = /** @class */ (function () {
    function BusinessObjectDefinitionDescriptionSuggestionService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectDefinitionDescriptionSuggestionService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectDefinitionDescriptionSuggestionService.prototype.businessObjectDefinitionDescriptionSuggestionAcceptBusinessObjectDefinitionDescriptionSuggestion = function (businessObjectDefinitionDescriptionSuggestionAcceptanceRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDefinitionDescriptionSuggestionAcceptanceRequest === null || businessObjectDefinitionDescriptionSuggestionAcceptanceRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionDescriptionSuggestionAcceptanceRequest was null or undefined when calling businessObjectDefinitionDescriptionSuggestionAcceptBusinessObjectDefinitionDescriptionSuggestion.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectDefinitionDescriptionSuggestions/acceptance", businessObjectDefinitionDescriptionSuggestionAcceptanceRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionDescriptionSuggestionService.prototype.businessObjectDefinitionDescriptionSuggestionCreateBusinessObjectDefinitionDescriptionSuggestion = function (businessObjectDefinitionDescriptionSuggestionCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDefinitionDescriptionSuggestionCreateRequest === null || businessObjectDefinitionDescriptionSuggestionCreateRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionDescriptionSuggestionCreateRequest was null or undefined when calling businessObjectDefinitionDescriptionSuggestionCreateBusinessObjectDefinitionDescriptionSuggestion.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectDefinitionDescriptionSuggestions", businessObjectDefinitionDescriptionSuggestionCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionDescriptionSuggestionService.prototype.businessObjectDefinitionDescriptionSuggestionDeleteBusinessObjectDefinitionDescriptionSuggestion = function (namespace, businessObjectDefinitionName, userId, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionDescriptionSuggestionDeleteBusinessObjectDefinitionDescriptionSuggestion.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionDescriptionSuggestionDeleteBusinessObjectDefinitionDescriptionSuggestion.');
        }
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling businessObjectDefinitionDescriptionSuggestionDeleteBusinessObjectDefinitionDescriptionSuggestion.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectDefinitionDescriptionSuggestions/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/userIds/" + encodeURIComponent(String(userId)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionDescriptionSuggestionService.prototype.businessObjectDefinitionDescriptionSuggestionGetBusinessObjectDefinitionDescriptionSuggestionByKey = function (namespace, businessObjectDefinitionName, userId, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionDescriptionSuggestionGetBusinessObjectDefinitionDescriptionSuggestionByKey.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionDescriptionSuggestionGetBusinessObjectDefinitionDescriptionSuggestionByKey.');
        }
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling businessObjectDefinitionDescriptionSuggestionGetBusinessObjectDefinitionDescriptionSuggestionByKey.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDefinitionDescriptionSuggestions/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/userIds/" + encodeURIComponent(String(userId)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionDescriptionSuggestionService.prototype.businessObjectDefinitionDescriptionSuggestionGetBusinessObjectDefinitionDescriptionSuggestions = function (namespace, businessObjectDefinitionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionDescriptionSuggestionGetBusinessObjectDefinitionDescriptionSuggestions.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionDescriptionSuggestionGetBusinessObjectDefinitionDescriptionSuggestions.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDefinitionDescriptionSuggestions/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionDescriptionSuggestionService.prototype.businessObjectDefinitionDescriptionSuggestionSearchBusinessObjectDefinitionDescriptionSuggestions = function (businessObjectDefinitionDescriptionSuggestionSearchRequest, fields, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDefinitionDescriptionSuggestionSearchRequest === null || businessObjectDefinitionDescriptionSuggestionSearchRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionDescriptionSuggestionSearchRequest was null or undefined when calling businessObjectDefinitionDescriptionSuggestionSearchBusinessObjectDefinitionDescriptionSuggestions.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (fields !== undefined && fields !== null) {
            queryParameters = queryParameters.set('fields', fields);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectDefinitionDescriptionSuggestions/search", businessObjectDefinitionDescriptionSuggestionSearchRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionDescriptionSuggestionService.prototype.businessObjectDefinitionDescriptionSuggestionUpdateBusinessObjectDefinitionDescriptionSuggestion = function (namespace, businessObjectDefinitionName, userId, businessObjectDefinitionDescriptionSuggestionUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionDescriptionSuggestionUpdateBusinessObjectDefinitionDescriptionSuggestion.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionDescriptionSuggestionUpdateBusinessObjectDefinitionDescriptionSuggestion.');
        }
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling businessObjectDefinitionDescriptionSuggestionUpdateBusinessObjectDefinitionDescriptionSuggestion.');
        }
        if (businessObjectDefinitionDescriptionSuggestionUpdateRequest === null || businessObjectDefinitionDescriptionSuggestionUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionDescriptionSuggestionUpdateRequest was null or undefined when calling businessObjectDefinitionDescriptionSuggestionUpdateBusinessObjectDefinitionDescriptionSuggestion.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectDefinitionDescriptionSuggestions/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/userIds/" + encodeURIComponent(String(userId)), businessObjectDefinitionDescriptionSuggestionUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionDescriptionSuggestionService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectDefinitionDescriptionSuggestionService_Factory() { return new BusinessObjectDefinitionDescriptionSuggestionService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectDefinitionDescriptionSuggestionService, providedIn: "root" });
    BusinessObjectDefinitionDescriptionSuggestionService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectDefinitionDescriptionSuggestionService);
    return BusinessObjectDefinitionDescriptionSuggestionService;
}());

var BusinessObjectDefinitionSubjectMatterExpertService = /** @class */ (function () {
    function BusinessObjectDefinitionSubjectMatterExpertService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectDefinitionSubjectMatterExpertService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectDefinitionSubjectMatterExpertService.prototype.businessObjectDefinitionSubjectMatterExpertCreateBusinessObjectDefinitionSubjectMatterExpert = function (businessObjectDefinitionSubjectMatterExpertCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDefinitionSubjectMatterExpertCreateRequest === null || businessObjectDefinitionSubjectMatterExpertCreateRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionSubjectMatterExpertCreateRequest was null or undefined when calling businessObjectDefinitionSubjectMatterExpertCreateBusinessObjectDefinitionSubjectMatterExpert.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectDefinitionSubjectMatterExperts", businessObjectDefinitionSubjectMatterExpertCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionSubjectMatterExpertService.prototype.businessObjectDefinitionSubjectMatterExpertDeleteBusinessObjectDefinitionSubjectMatterExpert = function (namespace, businessObjectDefinitionName, userId, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionSubjectMatterExpertDeleteBusinessObjectDefinitionSubjectMatterExpert.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionSubjectMatterExpertDeleteBusinessObjectDefinitionSubjectMatterExpert.');
        }
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling businessObjectDefinitionSubjectMatterExpertDeleteBusinessObjectDefinitionSubjectMatterExpert.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectDefinitionSubjectMatterExperts/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/userIds/" + encodeURIComponent(String(userId)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionSubjectMatterExpertService.prototype.businessObjectDefinitionSubjectMatterExpertDeleteBusinessObjectDefinitionSubjectMatterExpertsByBusinessObjectDefinition = function (namespace, businessObjectDefinitionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionSubjectMatterExpertDeleteBusinessObjectDefinitionSubjectMatterExpertsByBusinessObjectDefinition.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionSubjectMatterExpertDeleteBusinessObjectDefinitionSubjectMatterExpertsByBusinessObjectDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectDefinitionSubjectMatterExperts/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionSubjectMatterExpertService.prototype.businessObjectDefinitionSubjectMatterExpertGetBusinessObjectDefinitionSubjectMatterExpertsByBusinessObjectDefinition = function (namespace, businessObjectDefinitionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionSubjectMatterExpertGetBusinessObjectDefinitionSubjectMatterExpertsByBusinessObjectDefinition.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionSubjectMatterExpertGetBusinessObjectDefinitionSubjectMatterExpertsByBusinessObjectDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDefinitionSubjectMatterExperts/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionSubjectMatterExpertService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectDefinitionSubjectMatterExpertService_Factory() { return new BusinessObjectDefinitionSubjectMatterExpertService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectDefinitionSubjectMatterExpertService, providedIn: "root" });
    BusinessObjectDefinitionSubjectMatterExpertService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectDefinitionSubjectMatterExpertService);
    return BusinessObjectDefinitionSubjectMatterExpertService;
}());

var BusinessObjectDefinitionTagService = /** @class */ (function () {
    function BusinessObjectDefinitionTagService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectDefinitionTagService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectDefinitionTagService.prototype.businessObjectDefinitionTagCreateBusinessObjectDefinitionTag = function (businessObjectDefinitionTagCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDefinitionTagCreateRequest === null || businessObjectDefinitionTagCreateRequest === undefined) {
            throw new Error('Required parameter businessObjectDefinitionTagCreateRequest was null or undefined when calling businessObjectDefinitionTagCreateBusinessObjectDefinitionTag.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectDefinitionTags", businessObjectDefinitionTagCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionTagService.prototype.businessObjectDefinitionTagDeleteBusinessObjectDefinitionTag = function (namespace, businessObjectDefinitionName, tagTypeCode, tagCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionTagDeleteBusinessObjectDefinitionTag.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionTagDeleteBusinessObjectDefinitionTag.');
        }
        if (tagTypeCode === null || tagTypeCode === undefined) {
            throw new Error('Required parameter tagTypeCode was null or undefined when calling businessObjectDefinitionTagDeleteBusinessObjectDefinitionTag.');
        }
        if (tagCode === null || tagCode === undefined) {
            throw new Error('Required parameter tagCode was null or undefined when calling businessObjectDefinitionTagDeleteBusinessObjectDefinitionTag.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectDefinitionTags/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/tagTypes/" + encodeURIComponent(String(tagTypeCode)) + "/tagCodes/" + encodeURIComponent(String(tagCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionTagService.prototype.businessObjectDefinitionTagGetBusinessObjectDefinitionTagsByBusinessObjectDefinition = function (namespace, businessObjectDefinitionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectDefinitionTagGetBusinessObjectDefinitionTagsByBusinessObjectDefinition.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectDefinitionTagGetBusinessObjectDefinitionTagsByBusinessObjectDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDefinitionTags/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionTagService.prototype.businessObjectDefinitionTagGetBusinessObjectDefinitionTagsByTag = function (tagTypeCode, tagCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (tagTypeCode === null || tagTypeCode === undefined) {
            throw new Error('Required parameter tagTypeCode was null or undefined when calling businessObjectDefinitionTagGetBusinessObjectDefinitionTagsByTag.');
        }
        if (tagCode === null || tagCode === undefined) {
            throw new Error('Required parameter tagCode was null or undefined when calling businessObjectDefinitionTagGetBusinessObjectDefinitionTagsByTag.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectDefinitionTags/tagTypes/" + encodeURIComponent(String(tagTypeCode)) + "/tagCodes/" + encodeURIComponent(String(tagCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectDefinitionTagService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectDefinitionTagService_Factory() { return new BusinessObjectDefinitionTagService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectDefinitionTagService, providedIn: "root" });
    BusinessObjectDefinitionTagService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectDefinitionTagService);
    return BusinessObjectDefinitionTagService;
}());

var BusinessObjectFormatService = /** @class */ (function () {
    function BusinessObjectFormatService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectFormatService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectFormatService.prototype.businessObjectFormatCreateBusinessObjectFormat = function (businessObjectFormatCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectFormatCreateRequest === null || businessObjectFormatCreateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatCreateRequest was null or undefined when calling businessObjectFormatCreateBusinessObjectFormat.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectFormats", businessObjectFormatCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatDeleteBusinessObjectFormat = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatDeleteBusinessObjectFormat.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatDeleteBusinessObjectFormat.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatDeleteBusinessObjectFormat.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatDeleteBusinessObjectFormat.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectFormatDeleteBusinessObjectFormat.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectFormats/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatGenerateBusinessObjectFormatDdl = function (businessObjectFormatDdlRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectFormatDdlRequest === null || businessObjectFormatDdlRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatDdlRequest was null or undefined when calling businessObjectFormatGenerateBusinessObjectFormatDdl.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectFormats/generateDdl", businessObjectFormatDdlRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatGenerateBusinessObjectFormatDdlCollection = function (businessObjectFormatDdlCollectionRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectFormatDdlCollectionRequest === null || businessObjectFormatDdlCollectionRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatDdlCollectionRequest was null or undefined when calling businessObjectFormatGenerateBusinessObjectFormatDdlCollection.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectFormats/generateDdlCollection", businessObjectFormatDdlCollectionRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatGetBusinessObjectFormat = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatGetBusinessObjectFormat.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatGetBusinessObjectFormat.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatGetBusinessObjectFormat.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatGetBusinessObjectFormat.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (businessObjectFormatVersion !== undefined && businessObjectFormatVersion !== null) {
            queryParameters = queryParameters.set('businessObjectFormatVersion', businessObjectFormatVersion);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectFormats/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatGetBusinessObjectFormats = function (namespace, businessObjectDefinitionName, latestBusinessObjectFormatVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatGetBusinessObjectFormats.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatGetBusinessObjectFormats.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (latestBusinessObjectFormatVersion !== undefined && latestBusinessObjectFormatVersion !== null) {
            queryParameters = queryParameters.set('latestBusinessObjectFormatVersion', latestBusinessObjectFormatVersion);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectFormats/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatGetBusinessObjectFormatsWithFilters = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, latestBusinessObjectFormatVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatGetBusinessObjectFormatsWithFilters.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatGetBusinessObjectFormatsWithFilters.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatGetBusinessObjectFormatsWithFilters.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (latestBusinessObjectFormatVersion !== undefined && latestBusinessObjectFormatVersion !== null) {
            queryParameters = queryParameters.set('latestBusinessObjectFormatVersion', latestBusinessObjectFormatVersion);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectFormats/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatSearchBusinessObjectFormats = function (businessObjectFormatSearchRequest, fields, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectFormatSearchRequest === null || businessObjectFormatSearchRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatSearchRequest was null or undefined when calling businessObjectFormatSearchBusinessObjectFormats.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (fields !== undefined && fields !== null) {
            queryParameters = queryParameters.set('fields', fields);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectFormats/search", businessObjectFormatSearchRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatUpdateBusinessObjectFormat = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, businessObjectFormatUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormat.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormat.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormat.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormat.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormat.');
        }
        if (businessObjectFormatUpdateRequest === null || businessObjectFormatUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatUpdateRequest was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormat.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectFormats/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)), businessObjectFormatUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatUpdateBusinessObjectFormatAttributeDefinitions = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, businessObjectFormatAttributeDefinitionsUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAttributeDefinitions.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAttributeDefinitions.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAttributeDefinitions.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAttributeDefinitions.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAttributeDefinitions.');
        }
        if (businessObjectFormatAttributeDefinitionsUpdateRequest === null || businessObjectFormatAttributeDefinitionsUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatAttributeDefinitionsUpdateRequest was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAttributeDefinitions.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectFormatAttributeDefinitions/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)), businessObjectFormatAttributeDefinitionsUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatUpdateBusinessObjectFormatAttributes = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, businessObjectFormatAttributesUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAttributes.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAttributes.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAttributes.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAttributes.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAttributes.');
        }
        if (businessObjectFormatAttributesUpdateRequest === null || businessObjectFormatAttributesUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatAttributesUpdateRequest was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAttributes.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectFormatAttributes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)), businessObjectFormatAttributesUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatUpdateBusinessObjectFormatAvailabilityDay = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatAvailabilityDayUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAvailabilityDay.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAvailabilityDay.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAvailabilityDay.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAvailabilityDay.');
        }
        if (businessObjectFormatAvailabilityDayUpdateRequest === null || businessObjectFormatAvailabilityDayUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatAvailabilityDayUpdateRequest was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatAvailabilityDay.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectFormatAvailabilityDay/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)), businessObjectFormatAvailabilityDayUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatUpdateBusinessObjectFormatLegalHold = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatLegalHoldUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatLegalHold.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatLegalHold.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatLegalHold.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatLegalHold.');
        }
        if (businessObjectFormatLegalHoldUpdateRequest === null || businessObjectFormatLegalHoldUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatLegalHoldUpdateRequest was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatLegalHold.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectFormatLegalHold/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)), businessObjectFormatLegalHoldUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatUpdateBusinessObjectFormatParents = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatParentsUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatParents.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatParents.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatParents.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatParents.');
        }
        if (businessObjectFormatParentsUpdateRequest === null || businessObjectFormatParentsUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatParentsUpdateRequest was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatParents.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectFormatParents/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)), businessObjectFormatParentsUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatUpdateBusinessObjectFormatPublishingFrequency = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatPublishingFrequencyUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatPublishingFrequency.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatPublishingFrequency.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatPublishingFrequency.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatPublishingFrequency.');
        }
        if (businessObjectFormatPublishingFrequencyUpdateRequest === null || businessObjectFormatPublishingFrequencyUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatPublishingFrequencyUpdateRequest was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatPublishingFrequency.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectFormatPublishingFrequency/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)), businessObjectFormatPublishingFrequencyUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatUpdateBusinessObjectFormatRecordFlag = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatRecordFlagUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatRecordFlag.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatRecordFlag.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatRecordFlag.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatRecordFlag.');
        }
        if (businessObjectFormatRecordFlagUpdateRequest === null || businessObjectFormatRecordFlagUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatRecordFlagUpdateRequest was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatRecordFlag.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectFormatRecordFlag/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)), businessObjectFormatRecordFlagUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatUpdateBusinessObjectFormatRetentionInformation = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatRetentionInformationUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatRetentionInformation.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatRetentionInformation.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatRetentionInformation.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatRetentionInformation.');
        }
        if (businessObjectFormatRetentionInformationUpdateRequest === null || businessObjectFormatRetentionInformationUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatRetentionInformationUpdateRequest was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatRetentionInformation.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectFormatRetentionInformation/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)), businessObjectFormatRetentionInformationUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatUpdateBusinessObjectFormatSampleQuery = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatSampleQueryUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSampleQuery.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSampleQuery.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSampleQuery.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSampleQuery.');
        }
        if (businessObjectFormatSampleQueryUpdateRequest === null || businessObjectFormatSampleQueryUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatSampleQueryUpdateRequest was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSampleQuery.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectFormatSampleQuery/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)), businessObjectFormatSampleQueryUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatUpdateBusinessObjectFormatSchemaBackwardsCompatibleChanges = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatSchemaBackwardsCompatibilityUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSchemaBackwardsCompatibleChanges.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSchemaBackwardsCompatibleChanges.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSchemaBackwardsCompatibleChanges.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSchemaBackwardsCompatibleChanges.');
        }
        if (businessObjectFormatSchemaBackwardsCompatibilityUpdateRequest === null || businessObjectFormatSchemaBackwardsCompatibilityUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatSchemaBackwardsCompatibilityUpdateRequest was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSchemaBackwardsCompatibleChanges.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectFormatSchemaBackwardsCompatibility/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)), businessObjectFormatSchemaBackwardsCompatibilityUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatUpdateBusinessObjectFormatSingletonType = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatSingletonTypeUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSingletonType.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSingletonType.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSingletonType.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSingletonType.');
        }
        if (businessObjectFormatSingletonTypeUpdateRequest === null || businessObjectFormatSingletonTypeUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatSingletonTypeUpdateRequest was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatSingletonType.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectFormatSingletonType/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)), businessObjectFormatSingletonTypeUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.prototype.businessObjectFormatUpdateBusinessObjectFormatUsageNotes = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatUsageNotesUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatUsageNotes.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatUsageNotes.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatUsageNotes.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatUsageNotes.');
        }
        if (businessObjectFormatUsageNotesUpdateRequest === null || businessObjectFormatUsageNotesUpdateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatUsageNotesUpdateRequest was null or undefined when calling businessObjectFormatUpdateBusinessObjectFormatUsageNotes.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/businessObjectFormatUsageNotes/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)), businessObjectFormatUsageNotesUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectFormatService_Factory() { return new BusinessObjectFormatService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectFormatService, providedIn: "root" });
    BusinessObjectFormatService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectFormatService);
    return BusinessObjectFormatService;
}());

var BusinessObjectFormatExternalInterfaceDescriptiveInformationService = /** @class */ (function () {
    function BusinessObjectFormatExternalInterfaceDescriptiveInformationService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectFormatExternalInterfaceDescriptiveInformationService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectFormatExternalInterfaceDescriptiveInformationService.prototype.businessObjectFormatExternalInterfaceDescriptiveInformationGetBusinessObjectFormatExternalInterface = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, externalInterfaceName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormatExternalInterfaceDescriptiveInformationGetBusinessObjectFormatExternalInterface.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormatExternalInterfaceDescriptiveInformationGetBusinessObjectFormatExternalInterface.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormatExternalInterfaceDescriptiveInformationGetBusinessObjectFormatExternalInterface.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormatExternalInterfaceDescriptiveInformationGetBusinessObjectFormatExternalInterface.');
        }
        if (externalInterfaceName === null || externalInterfaceName === undefined) {
            throw new Error('Required parameter externalInterfaceName was null or undefined when calling businessObjectFormatExternalInterfaceDescriptiveInformationGetBusinessObjectFormatExternalInterface.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectFormatExternalInterfaceDescriptiveInformation/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/externalInterfaceNames/" + encodeURIComponent(String(externalInterfaceName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatExternalInterfaceDescriptiveInformationService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectFormatExternalInterfaceDescriptiveInformationService_Factory() { return new BusinessObjectFormatExternalInterfaceDescriptiveInformationService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectFormatExternalInterfaceDescriptiveInformationService, providedIn: "root" });
    BusinessObjectFormatExternalInterfaceDescriptiveInformationService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectFormatExternalInterfaceDescriptiveInformationService);
    return BusinessObjectFormatExternalInterfaceDescriptiveInformationService;
}());

var BusinessObjectFormatToExternalInterfaceMappingService = /** @class */ (function () {
    function BusinessObjectFormatToExternalInterfaceMappingService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    BusinessObjectFormatToExternalInterfaceMappingService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    BusinessObjectFormatToExternalInterfaceMappingService.prototype.businessObjectFormattoExternalInterfaceMappingCreateBusinessObjectFormatExternalInterface = function (businessObjectFormatExternalInterfaceCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectFormatExternalInterfaceCreateRequest === null || businessObjectFormatExternalInterfaceCreateRequest === undefined) {
            throw new Error('Required parameter businessObjectFormatExternalInterfaceCreateRequest was null or undefined when calling businessObjectFormattoExternalInterfaceMappingCreateBusinessObjectFormatExternalInterface.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/businessObjectFormatExternalInterfaces", businessObjectFormatExternalInterfaceCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatToExternalInterfaceMappingService.prototype.businessObjectFormattoExternalInterfaceMappingDeleteBusinessObjectFormatExternalInterface = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, externalInterfaceName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormattoExternalInterfaceMappingDeleteBusinessObjectFormatExternalInterface.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormattoExternalInterfaceMappingDeleteBusinessObjectFormatExternalInterface.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormattoExternalInterfaceMappingDeleteBusinessObjectFormatExternalInterface.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormattoExternalInterfaceMappingDeleteBusinessObjectFormatExternalInterface.');
        }
        if (externalInterfaceName === null || externalInterfaceName === undefined) {
            throw new Error('Required parameter externalInterfaceName was null or undefined when calling businessObjectFormattoExternalInterfaceMappingDeleteBusinessObjectFormatExternalInterface.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/businessObjectFormatExternalInterfaces/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/externalInterfaceNames/" + encodeURIComponent(String(externalInterfaceName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatToExternalInterfaceMappingService.prototype.businessObjectFormattoExternalInterfaceMappingGetBusinessObjectFormatExternalInterface = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, externalInterfaceName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling businessObjectFormattoExternalInterfaceMappingGetBusinessObjectFormatExternalInterface.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling businessObjectFormattoExternalInterfaceMappingGetBusinessObjectFormatExternalInterface.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling businessObjectFormattoExternalInterfaceMappingGetBusinessObjectFormatExternalInterface.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling businessObjectFormattoExternalInterfaceMappingGetBusinessObjectFormatExternalInterface.');
        }
        if (externalInterfaceName === null || externalInterfaceName === undefined) {
            throw new Error('Required parameter externalInterfaceName was null or undefined when calling businessObjectFormattoExternalInterfaceMappingGetBusinessObjectFormatExternalInterface.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/businessObjectFormatExternalInterfaces/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/externalInterfaceNames/" + encodeURIComponent(String(externalInterfaceName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    BusinessObjectFormatToExternalInterfaceMappingService.ɵprov = ɵɵdefineInjectable({ factory: function BusinessObjectFormatToExternalInterfaceMappingService_Factory() { return new BusinessObjectFormatToExternalInterfaceMappingService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: BusinessObjectFormatToExternalInterfaceMappingService, providedIn: "root" });
    BusinessObjectFormatToExternalInterfaceMappingService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], BusinessObjectFormatToExternalInterfaceMappingService);
    return BusinessObjectFormatToExternalInterfaceMappingService;
}());

var ConfigurationEntryService = /** @class */ (function () {
    function ConfigurationEntryService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    ConfigurationEntryService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    ConfigurationEntryService.prototype.configurationEntryGetConfigurationEntries = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/configurationEntries", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ConfigurationEntryService.prototype.configurationEntryGetConfigurationEntry = function (configurationEntryKey, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (configurationEntryKey === null || configurationEntryKey === undefined) {
            throw new Error('Required parameter configurationEntryKey was null or undefined when calling configurationEntryGetConfigurationEntry.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/configurationEntries/" + encodeURIComponent(String(configurationEntryKey)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ConfigurationEntryService.ɵprov = ɵɵdefineInjectable({ factory: function ConfigurationEntryService_Factory() { return new ConfigurationEntryService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: ConfigurationEntryService, providedIn: "root" });
    ConfigurationEntryService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], ConfigurationEntryService);
    return ConfigurationEntryService;
}());

var CurrentUserService = /** @class */ (function () {
    function CurrentUserService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    CurrentUserService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    CurrentUserService.prototype.currentUserGetCurrentUser = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/currentUser", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CurrentUserService.ɵprov = ɵɵdefineInjectable({ factory: function CurrentUserService_Factory() { return new CurrentUserService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: CurrentUserService, providedIn: "root" });
    CurrentUserService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], CurrentUserService);
    return CurrentUserService;
}());

var CustomDDLService = /** @class */ (function () {
    function CustomDDLService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    CustomDDLService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    CustomDDLService.prototype.customDDLCreateCustomDdl = function (customDdlCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (customDdlCreateRequest === null || customDdlCreateRequest === undefined) {
            throw new Error('Required parameter customDdlCreateRequest was null or undefined when calling customDDLCreateCustomDdl.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/customDdls", customDdlCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomDDLService.prototype.customDDLDeleteCustomDdl = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, customDdlName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling customDDLDeleteCustomDdl.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling customDDLDeleteCustomDdl.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling customDDLDeleteCustomDdl.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling customDDLDeleteCustomDdl.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling customDDLDeleteCustomDdl.');
        }
        if (customDdlName === null || customDdlName === undefined) {
            throw new Error('Required parameter customDdlName was null or undefined when calling customDDLDeleteCustomDdl.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/customDdls/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/customDdlNames/" + encodeURIComponent(String(customDdlName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomDDLService.prototype.customDDLGetCustomDdl = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, customDdlName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling customDDLGetCustomDdl.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling customDDLGetCustomDdl.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling customDDLGetCustomDdl.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling customDDLGetCustomDdl.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling customDDLGetCustomDdl.');
        }
        if (customDdlName === null || customDdlName === undefined) {
            throw new Error('Required parameter customDdlName was null or undefined when calling customDDLGetCustomDdl.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/customDdls/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/customDdlNames/" + encodeURIComponent(String(customDdlName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomDDLService.prototype.customDDLGetCustomDdls = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling customDDLGetCustomDdls.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling customDDLGetCustomDdls.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling customDDLGetCustomDdls.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling customDDLGetCustomDdls.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling customDDLGetCustomDdls.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/customDdls/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomDDLService.prototype.customDDLUpdateCustomDdl = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, customDdlName, customDdlUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling customDDLUpdateCustomDdl.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling customDDLUpdateCustomDdl.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling customDDLUpdateCustomDdl.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling customDDLUpdateCustomDdl.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling customDDLUpdateCustomDdl.');
        }
        if (customDdlName === null || customDdlName === undefined) {
            throw new Error('Required parameter customDdlName was null or undefined when calling customDDLUpdateCustomDdl.');
        }
        if (customDdlUpdateRequest === null || customDdlUpdateRequest === undefined) {
            throw new Error('Required parameter customDdlUpdateRequest was null or undefined when calling customDDLUpdateCustomDdl.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/customDdls/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/customDdlNames/" + encodeURIComponent(String(customDdlName)), customDdlUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomDDLService.ɵprov = ɵɵdefineInjectable({ factory: function CustomDDLService_Factory() { return new CustomDDLService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: CustomDDLService, providedIn: "root" });
    CustomDDLService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], CustomDDLService);
    return CustomDDLService;
}());

var DataProviderService = /** @class */ (function () {
    function DataProviderService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    DataProviderService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    DataProviderService.prototype.dataProviderCreateDataProvider = function (dataProviderCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (dataProviderCreateRequest === null || dataProviderCreateRequest === undefined) {
            throw new Error('Required parameter dataProviderCreateRequest was null or undefined when calling dataProviderCreateDataProvider.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/dataProviders", dataProviderCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    DataProviderService.prototype.dataProviderDeleteDataProvider = function (dataProviderName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (dataProviderName === null || dataProviderName === undefined) {
            throw new Error('Required parameter dataProviderName was null or undefined when calling dataProviderDeleteDataProvider.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/dataProviders/" + encodeURIComponent(String(dataProviderName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    DataProviderService.prototype.dataProviderGetDataProvider = function (dataProviderName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (dataProviderName === null || dataProviderName === undefined) {
            throw new Error('Required parameter dataProviderName was null or undefined when calling dataProviderGetDataProvider.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/dataProviders/" + encodeURIComponent(String(dataProviderName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    DataProviderService.prototype.dataProviderGetDataProviders = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/dataProviders", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    DataProviderService.ɵprov = ɵɵdefineInjectable({ factory: function DataProviderService_Factory() { return new DataProviderService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: DataProviderService, providedIn: "root" });
    DataProviderService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], DataProviderService);
    return DataProviderService;
}());

var DepartmentService = /** @class */ (function () {
    function DepartmentService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    DepartmentService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    DepartmentService.prototype.departmentCreateDepartment = function (departmentCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (departmentCreateRequest === null || departmentCreateRequest === undefined) {
            throw new Error('Required parameter departmentCreateRequest was null or undefined when calling departmentCreateDepartment.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/departments", departmentCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    DepartmentService.prototype.departmentDeleteDepartment = function (departmentCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (departmentCode === null || departmentCode === undefined) {
            throw new Error('Required parameter departmentCode was null or undefined when calling departmentDeleteDepartment.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/departments/" + encodeURIComponent(String(departmentCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    DepartmentService.prototype.departmentGetDepartment = function (departmentCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (departmentCode === null || departmentCode === undefined) {
            throw new Error('Required parameter departmentCode was null or undefined when calling departmentGetDepartment.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/departments/" + encodeURIComponent(String(departmentCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    DepartmentService.prototype.departmentGetDepartments = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/departments", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    DepartmentService.ɵprov = ɵɵdefineInjectable({ factory: function DepartmentService_Factory() { return new DepartmentService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: DepartmentService, providedIn: "root" });
    DepartmentService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], DepartmentService);
    return DepartmentService;
}());

var EMRService = /** @class */ (function () {
    function EMRService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    EMRService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    EMRService.prototype.eMRAddHadoopJarStepToEmrCluster = function (emrHadoopJarStepAddRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (emrHadoopJarStepAddRequest === null || emrHadoopJarStepAddRequest === undefined) {
            throw new Error('Required parameter emrHadoopJarStepAddRequest was null or undefined when calling eMRAddHadoopJarStepToEmrCluster.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/emrHadoopJarSteps", emrHadoopJarStepAddRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EMRService.prototype.eMRAddHiveStepToEmrCluster = function (emrHiveStepAddRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (emrHiveStepAddRequest === null || emrHiveStepAddRequest === undefined) {
            throw new Error('Required parameter emrHiveStepAddRequest was null or undefined when calling eMRAddHiveStepToEmrCluster.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/emrHiveSteps", emrHiveStepAddRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EMRService.prototype.eMRAddPigStepToEmrCluster = function (emrPigStepAddRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (emrPigStepAddRequest === null || emrPigStepAddRequest === undefined) {
            throw new Error('Required parameter emrPigStepAddRequest was null or undefined when calling eMRAddPigStepToEmrCluster.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/emrPigSteps", emrPigStepAddRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EMRService.prototype.eMRAddShellStepToEmrCluster = function (emrShellStepAddRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (emrShellStepAddRequest === null || emrShellStepAddRequest === undefined) {
            throw new Error('Required parameter emrShellStepAddRequest was null or undefined when calling eMRAddShellStepToEmrCluster.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/emrShellSteps", emrShellStepAddRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EMRService.prototype.eMRCreateEmrCluster = function (emrClusterCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (emrClusterCreateRequest === null || emrClusterCreateRequest === undefined) {
            throw new Error('Required parameter emrClusterCreateRequest was null or undefined when calling eMRCreateEmrCluster.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/emrClusters", emrClusterCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EMRService.prototype.eMRGetEmrCluster = function (namespace, emrClusterDefinitionName, emrClusterName, emrClusterId, emrStepId, verbose, accountId, retrieveInstanceFleets, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling eMRGetEmrCluster.');
        }
        if (emrClusterDefinitionName === null || emrClusterDefinitionName === undefined) {
            throw new Error('Required parameter emrClusterDefinitionName was null or undefined when calling eMRGetEmrCluster.');
        }
        if (emrClusterName === null || emrClusterName === undefined) {
            throw new Error('Required parameter emrClusterName was null or undefined when calling eMRGetEmrCluster.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (emrClusterId !== undefined && emrClusterId !== null) {
            queryParameters = queryParameters.set('emrClusterId', emrClusterId);
        }
        if (emrStepId !== undefined && emrStepId !== null) {
            queryParameters = queryParameters.set('emrStepId', emrStepId);
        }
        if (verbose !== undefined && verbose !== null) {
            queryParameters = queryParameters.set('verbose', verbose);
        }
        if (accountId !== undefined && accountId !== null) {
            queryParameters = queryParameters.set('accountId', accountId);
        }
        if (retrieveInstanceFleets !== undefined && retrieveInstanceFleets !== null) {
            queryParameters = queryParameters.set('retrieveInstanceFleets', retrieveInstanceFleets);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/emrClusters/namespaces/" + encodeURIComponent(String(namespace)) + "/emrClusterDefinitionNames/" + encodeURIComponent(String(emrClusterDefinitionName)) + "/emrClusterNames/" + encodeURIComponent(String(emrClusterName)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EMRService.prototype.eMRTerminateEmrCluster = function (namespace, emrClusterDefinitionName, emrClusterName, overrideTerminationProtection, emrClusterId, accountId, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling eMRTerminateEmrCluster.');
        }
        if (emrClusterDefinitionName === null || emrClusterDefinitionName === undefined) {
            throw new Error('Required parameter emrClusterDefinitionName was null or undefined when calling eMRTerminateEmrCluster.');
        }
        if (emrClusterName === null || emrClusterName === undefined) {
            throw new Error('Required parameter emrClusterName was null or undefined when calling eMRTerminateEmrCluster.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (overrideTerminationProtection !== undefined && overrideTerminationProtection !== null) {
            queryParameters = queryParameters.set('overrideTerminationProtection', overrideTerminationProtection);
        }
        if (emrClusterId !== undefined && emrClusterId !== null) {
            queryParameters = queryParameters.set('emrClusterId', emrClusterId);
        }
        if (accountId !== undefined && accountId !== null) {
            queryParameters = queryParameters.set('accountId', accountId);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/emrClusters/namespaces/" + encodeURIComponent(String(namespace)) + "/emrClusterDefinitionNames/" + encodeURIComponent(String(emrClusterDefinitionName)) + "/emrClusterNames/" + encodeURIComponent(String(emrClusterName)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EMRService.ɵprov = ɵɵdefineInjectable({ factory: function EMRService_Factory() { return new EMRService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: EMRService, providedIn: "root" });
    EMRService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], EMRService);
    return EMRService;
}());

var EMRClusterDefinitionService = /** @class */ (function () {
    function EMRClusterDefinitionService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    EMRClusterDefinitionService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    EMRClusterDefinitionService.prototype.eMRClusterDefinitionCreateEmrClusterDefinition = function (emrClusterDefinitionCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (emrClusterDefinitionCreateRequest === null || emrClusterDefinitionCreateRequest === undefined) {
            throw new Error('Required parameter emrClusterDefinitionCreateRequest was null or undefined when calling eMRClusterDefinitionCreateEmrClusterDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/emrClusterDefinitions", emrClusterDefinitionCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EMRClusterDefinitionService.prototype.eMRClusterDefinitionDeleteEmrClusterDefinition = function (namespace, emrClusterDefinitionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling eMRClusterDefinitionDeleteEmrClusterDefinition.');
        }
        if (emrClusterDefinitionName === null || emrClusterDefinitionName === undefined) {
            throw new Error('Required parameter emrClusterDefinitionName was null or undefined when calling eMRClusterDefinitionDeleteEmrClusterDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/emrClusterDefinitions/namespaces/" + encodeURIComponent(String(namespace)) + "/emrClusterDefinitionNames/" + encodeURIComponent(String(emrClusterDefinitionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EMRClusterDefinitionService.prototype.eMRClusterDefinitionGetEmrClusterDefinition = function (namespace, emrClusterDefinitionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling eMRClusterDefinitionGetEmrClusterDefinition.');
        }
        if (emrClusterDefinitionName === null || emrClusterDefinitionName === undefined) {
            throw new Error('Required parameter emrClusterDefinitionName was null or undefined when calling eMRClusterDefinitionGetEmrClusterDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/emrClusterDefinitions/namespaces/" + encodeURIComponent(String(namespace)) + "/emrClusterDefinitionNames/" + encodeURIComponent(String(emrClusterDefinitionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EMRClusterDefinitionService.prototype.eMRClusterDefinitionGetEmrClusterDefinitions = function (namespace, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling eMRClusterDefinitionGetEmrClusterDefinitions.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/emrClusterDefinitions/namespaces/" + encodeURIComponent(String(namespace)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EMRClusterDefinitionService.prototype.eMRClusterDefinitionUpdateEmrClusterDefinition = function (namespace, emrClusterDefinitionName, emrClusterDefinitionUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling eMRClusterDefinitionUpdateEmrClusterDefinition.');
        }
        if (emrClusterDefinitionName === null || emrClusterDefinitionName === undefined) {
            throw new Error('Required parameter emrClusterDefinitionName was null or undefined when calling eMRClusterDefinitionUpdateEmrClusterDefinition.');
        }
        if (emrClusterDefinitionUpdateRequest === null || emrClusterDefinitionUpdateRequest === undefined) {
            throw new Error('Required parameter emrClusterDefinitionUpdateRequest was null or undefined when calling eMRClusterDefinitionUpdateEmrClusterDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/emrClusterDefinitions/namespaces/" + encodeURIComponent(String(namespace)) + "/emrClusterDefinitionNames/" + encodeURIComponent(String(emrClusterDefinitionName)), emrClusterDefinitionUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EMRClusterDefinitionService.ɵprov = ɵɵdefineInjectable({ factory: function EMRClusterDefinitionService_Factory() { return new EMRClusterDefinitionService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: EMRClusterDefinitionService, providedIn: "root" });
    EMRClusterDefinitionService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], EMRClusterDefinitionService);
    return EMRClusterDefinitionService;
}());

var ExpectedPartitionValueService = /** @class */ (function () {
    function ExpectedPartitionValueService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    ExpectedPartitionValueService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    ExpectedPartitionValueService.prototype.expectedPartitionValueCreateExpectedPartitionValues = function (expectedPartitionValuesCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (expectedPartitionValuesCreateRequest === null || expectedPartitionValuesCreateRequest === undefined) {
            throw new Error('Required parameter expectedPartitionValuesCreateRequest was null or undefined when calling expectedPartitionValueCreateExpectedPartitionValues.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/expectedPartitionValues", expectedPartitionValuesCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ExpectedPartitionValueService.prototype.expectedPartitionValueDeleteExpectedPartitionValues = function (expectedPartitionValuesDeleteRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (expectedPartitionValuesDeleteRequest === null || expectedPartitionValuesDeleteRequest === undefined) {
            throw new Error('Required parameter expectedPartitionValuesDeleteRequest was null or undefined when calling expectedPartitionValueDeleteExpectedPartitionValues.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/expectedPartitionValues", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ExpectedPartitionValueService.prototype.expectedPartitionValueGetExpectedPartitionValue = function (partitionKeyGroupName, expectedPartitionValue, offset, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (partitionKeyGroupName === null || partitionKeyGroupName === undefined) {
            throw new Error('Required parameter partitionKeyGroupName was null or undefined when calling expectedPartitionValueGetExpectedPartitionValue.');
        }
        if (expectedPartitionValue === null || expectedPartitionValue === undefined) {
            throw new Error('Required parameter expectedPartitionValue was null or undefined when calling expectedPartitionValueGetExpectedPartitionValue.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (offset !== undefined && offset !== null) {
            queryParameters = queryParameters.set('offset', offset);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/expectedPartitionValues/partitionKeyGroups/" + encodeURIComponent(String(partitionKeyGroupName)) + "/expectedPartitionValues/" + encodeURIComponent(String(expectedPartitionValue)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ExpectedPartitionValueService.prototype.expectedPartitionValueGetExpectedPartitionValues = function (partitionKeyGroupName, startExpectedPartitionValue, endExpectedPartitionValue, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (partitionKeyGroupName === null || partitionKeyGroupName === undefined) {
            throw new Error('Required parameter partitionKeyGroupName was null or undefined when calling expectedPartitionValueGetExpectedPartitionValues.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (startExpectedPartitionValue !== undefined && startExpectedPartitionValue !== null) {
            queryParameters = queryParameters.set('startExpectedPartitionValue', startExpectedPartitionValue);
        }
        if (endExpectedPartitionValue !== undefined && endExpectedPartitionValue !== null) {
            queryParameters = queryParameters.set('endExpectedPartitionValue', endExpectedPartitionValue);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/expectedPartitionValues/partitionKeyGroups/" + encodeURIComponent(String(partitionKeyGroupName)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ExpectedPartitionValueService.ɵprov = ɵɵdefineInjectable({ factory: function ExpectedPartitionValueService_Factory() { return new ExpectedPartitionValueService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: ExpectedPartitionValueService, providedIn: "root" });
    ExpectedPartitionValueService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], ExpectedPartitionValueService);
    return ExpectedPartitionValueService;
}());

var ExternalInterfaceService = /** @class */ (function () {
    function ExternalInterfaceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    ExternalInterfaceService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    ExternalInterfaceService.prototype.externalInterfaceCreateExternalInterface = function (externalInterfaceCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (externalInterfaceCreateRequest === null || externalInterfaceCreateRequest === undefined) {
            throw new Error('Required parameter externalInterfaceCreateRequest was null or undefined when calling externalInterfaceCreateExternalInterface.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/externalInterfaces", externalInterfaceCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ExternalInterfaceService.prototype.externalInterfaceDeleteExternalInterface = function (externalInterfaceName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (externalInterfaceName === null || externalInterfaceName === undefined) {
            throw new Error('Required parameter externalInterfaceName was null or undefined when calling externalInterfaceDeleteExternalInterface.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/externalInterfaces/" + encodeURIComponent(String(externalInterfaceName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ExternalInterfaceService.prototype.externalInterfaceGetExternalInterface = function (externalInterfaceName, includeBusinessObjectFormatExternalInterfaces, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (externalInterfaceName === null || externalInterfaceName === undefined) {
            throw new Error('Required parameter externalInterfaceName was null or undefined when calling externalInterfaceGetExternalInterface.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (includeBusinessObjectFormatExternalInterfaces !== undefined && includeBusinessObjectFormatExternalInterfaces !== null) {
            queryParameters = queryParameters.set('includeBusinessObjectFormatExternalInterfaces', includeBusinessObjectFormatExternalInterfaces);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/externalInterfaces/" + encodeURIComponent(String(externalInterfaceName)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ExternalInterfaceService.prototype.externalInterfaceGetExternalInterfaces = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/externalInterfaces", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ExternalInterfaceService.prototype.externalInterfaceUpdateExternalInterface = function (externalInterfaceName, externalInterfaceUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (externalInterfaceName === null || externalInterfaceName === undefined) {
            throw new Error('Required parameter externalInterfaceName was null or undefined when calling externalInterfaceUpdateExternalInterface.');
        }
        if (externalInterfaceUpdateRequest === null || externalInterfaceUpdateRequest === undefined) {
            throw new Error('Required parameter externalInterfaceUpdateRequest was null or undefined when calling externalInterfaceUpdateExternalInterface.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/externalInterfaces/" + encodeURIComponent(String(externalInterfaceName)), externalInterfaceUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ExternalInterfaceService.ɵprov = ɵɵdefineInjectable({ factory: function ExternalInterfaceService_Factory() { return new ExternalInterfaceService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: ExternalInterfaceService, providedIn: "root" });
    ExternalInterfaceService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], ExternalInterfaceService);
    return ExternalInterfaceService;
}());

var FileTypeService = /** @class */ (function () {
    function FileTypeService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    FileTypeService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    FileTypeService.prototype.fileTypeCreateFileType = function (fileTypeCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (fileTypeCreateRequest === null || fileTypeCreateRequest === undefined) {
            throw new Error('Required parameter fileTypeCreateRequest was null or undefined when calling fileTypeCreateFileType.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/fileTypes", fileTypeCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    FileTypeService.prototype.fileTypeDeleteFileType = function (fileTypeCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (fileTypeCode === null || fileTypeCode === undefined) {
            throw new Error('Required parameter fileTypeCode was null or undefined when calling fileTypeDeleteFileType.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/fileTypes/" + encodeURIComponent(String(fileTypeCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    FileTypeService.prototype.fileTypeGetFileType = function (fileTypeCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (fileTypeCode === null || fileTypeCode === undefined) {
            throw new Error('Required parameter fileTypeCode was null or undefined when calling fileTypeGetFileType.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/fileTypes/" + encodeURIComponent(String(fileTypeCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    FileTypeService.prototype.fileTypeGetFileTypes = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/fileTypes", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    FileTypeService.ɵprov = ɵɵdefineInjectable({ factory: function FileTypeService_Factory() { return new FileTypeService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: FileTypeService, providedIn: "root" });
    FileTypeService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], FileTypeService);
    return FileTypeService;
}());

var GlobalAttributeDefinitionService = /** @class */ (function () {
    function GlobalAttributeDefinitionService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    GlobalAttributeDefinitionService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    GlobalAttributeDefinitionService.prototype.globalAttributeDefinitionCreateGlobalAttributeDefinition = function (globalAttributeDefinitionCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (globalAttributeDefinitionCreateRequest === null || globalAttributeDefinitionCreateRequest === undefined) {
            throw new Error('Required parameter globalAttributeDefinitionCreateRequest was null or undefined when calling globalAttributeDefinitionCreateGlobalAttributeDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/globalAttributeDefinitions", globalAttributeDefinitionCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    GlobalAttributeDefinitionService.prototype.globalAttributeDefinitionDeleteGlobalAttributeDefinition = function (globalAttributeDefinitionLevel, globalAttributeDefinitionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (globalAttributeDefinitionLevel === null || globalAttributeDefinitionLevel === undefined) {
            throw new Error('Required parameter globalAttributeDefinitionLevel was null or undefined when calling globalAttributeDefinitionDeleteGlobalAttributeDefinition.');
        }
        if (globalAttributeDefinitionName === null || globalAttributeDefinitionName === undefined) {
            throw new Error('Required parameter globalAttributeDefinitionName was null or undefined when calling globalAttributeDefinitionDeleteGlobalAttributeDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/globalAttributeDefinitions/globalAttributeDefinitionLevels/" + encodeURIComponent(String(globalAttributeDefinitionLevel)) + "/globalAttributeDefinitionNames/" + encodeURIComponent(String(globalAttributeDefinitionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    GlobalAttributeDefinitionService.prototype.globalAttributeDefinitionGetGlobalAttributeDefinition = function (globalAttributeDefinitionLevel, globalAttributeDefinitionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (globalAttributeDefinitionLevel === null || globalAttributeDefinitionLevel === undefined) {
            throw new Error('Required parameter globalAttributeDefinitionLevel was null or undefined when calling globalAttributeDefinitionGetGlobalAttributeDefinition.');
        }
        if (globalAttributeDefinitionName === null || globalAttributeDefinitionName === undefined) {
            throw new Error('Required parameter globalAttributeDefinitionName was null or undefined when calling globalAttributeDefinitionGetGlobalAttributeDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/globalAttributeDefinitions/globalAttributeDefinitionLevels/" + encodeURIComponent(String(globalAttributeDefinitionLevel)) + "/globalAttributeDefinitionNames/" + encodeURIComponent(String(globalAttributeDefinitionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    GlobalAttributeDefinitionService.prototype.globalAttributeDefinitionGetGlobalAttributeDefinitions = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/globalAttributeDefinitions", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    GlobalAttributeDefinitionService.ɵprov = ɵɵdefineInjectable({ factory: function GlobalAttributeDefinitionService_Factory() { return new GlobalAttributeDefinitionService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: GlobalAttributeDefinitionService, providedIn: "root" });
    GlobalAttributeDefinitionService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], GlobalAttributeDefinitionService);
    return GlobalAttributeDefinitionService;
}());

var IndexSearchService = /** @class */ (function () {
    function IndexSearchService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    IndexSearchService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    IndexSearchService.prototype.indexSearchIndexSearch = function (indexSearchRequest, fields, match, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (indexSearchRequest === null || indexSearchRequest === undefined) {
            throw new Error('Required parameter indexSearchRequest was null or undefined when calling indexSearchIndexSearch.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (fields !== undefined && fields !== null) {
            queryParameters = queryParameters.set('fields', fields);
        }
        if (match !== undefined && match !== null) {
            queryParameters = queryParameters.set('match', match);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/indexSearch", indexSearchRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    IndexSearchService.ɵprov = ɵɵdefineInjectable({ factory: function IndexSearchService_Factory() { return new IndexSearchService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: IndexSearchService, providedIn: "root" });
    IndexSearchService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], IndexSearchService);
    return IndexSearchService;
}());

var JobService = /** @class */ (function () {
    function JobService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    JobService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    JobService.prototype.jobCreateJob = function (jobCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (jobCreateRequest === null || jobCreateRequest === undefined) {
            throw new Error('Required parameter jobCreateRequest was null or undefined when calling jobCreateJob.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/jobs", jobCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    JobService.prototype.jobDeleteJob = function (id, jobDeleteRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling jobDeleteJob.');
        }
        if (jobDeleteRequest === null || jobDeleteRequest === undefined) {
            throw new Error('Required parameter jobDeleteRequest was null or undefined when calling jobDeleteJob.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/jobs/ids/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    JobService.prototype.jobGetJob = function (id, verbose, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling jobGetJob.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (verbose !== undefined && verbose !== null) {
            queryParameters = queryParameters.set('verbose', verbose);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/jobs/ids/" + encodeURIComponent(String(id)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    JobService.prototype.jobGetJobs = function (namespace, jobName, status, startTime, endTime, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (namespace !== undefined && namespace !== null) {
            queryParameters = queryParameters.set('namespace', namespace);
        }
        if (jobName !== undefined && jobName !== null) {
            queryParameters = queryParameters.set('jobName', jobName);
        }
        if (status !== undefined && status !== null) {
            queryParameters = queryParameters.set('status', status);
        }
        if (startTime !== undefined && startTime !== null) {
            queryParameters = queryParameters.set('startTime', startTime);
        }
        if (endTime !== undefined && endTime !== null) {
            queryParameters = queryParameters.set('endTime', endTime);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/jobs", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    JobService.prototype.jobSignalJob = function (jobSignalRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (jobSignalRequest === null || jobSignalRequest === undefined) {
            throw new Error('Required parameter jobSignalRequest was null or undefined when calling jobSignalJob.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/jobs/signal", jobSignalRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    JobService.prototype.jobUpdateJob = function (id, jobUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling jobUpdateJob.');
        }
        if (jobUpdateRequest === null || jobUpdateRequest === undefined) {
            throw new Error('Required parameter jobUpdateRequest was null or undefined when calling jobUpdateJob.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/jobs/ids/" + encodeURIComponent(String(id)), jobUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    JobService.ɵprov = ɵɵdefineInjectable({ factory: function JobService_Factory() { return new JobService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: JobService, providedIn: "root" });
    JobService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], JobService);
    return JobService;
}());

var JobDefinitionService = /** @class */ (function () {
    function JobDefinitionService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    JobDefinitionService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    JobDefinitionService.prototype.jobDefinitionCreateJobDefinition = function (jobDefinitionCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (jobDefinitionCreateRequest === null || jobDefinitionCreateRequest === undefined) {
            throw new Error('Required parameter jobDefinitionCreateRequest was null or undefined when calling jobDefinitionCreateJobDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/jobDefinitions", jobDefinitionCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    JobDefinitionService.prototype.jobDefinitionGetJobDefinition = function (namespace, jobName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling jobDefinitionGetJobDefinition.');
        }
        if (jobName === null || jobName === undefined) {
            throw new Error('Required parameter jobName was null or undefined when calling jobDefinitionGetJobDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/jobDefinitions/namespaces/" + encodeURIComponent(String(namespace)) + "/jobNames/" + encodeURIComponent(String(jobName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    JobDefinitionService.prototype.jobDefinitionGetJobDefinitionKeys = function (namespace, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling jobDefinitionGetJobDefinitionKeys.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/jobDefinitions/namespaces/" + encodeURIComponent(String(namespace)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    JobDefinitionService.prototype.jobDefinitionUpdateJobDefinition = function (namespace, jobName, jobDefinitionUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling jobDefinitionUpdateJobDefinition.');
        }
        if (jobName === null || jobName === undefined) {
            throw new Error('Required parameter jobName was null or undefined when calling jobDefinitionUpdateJobDefinition.');
        }
        if (jobDefinitionUpdateRequest === null || jobDefinitionUpdateRequest === undefined) {
            throw new Error('Required parameter jobDefinitionUpdateRequest was null or undefined when calling jobDefinitionUpdateJobDefinition.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/jobDefinitions/namespaces/" + encodeURIComponent(String(namespace)) + "/jobNames/" + encodeURIComponent(String(jobName)), jobDefinitionUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    JobDefinitionService.ɵprov = ɵɵdefineInjectable({ factory: function JobDefinitionService_Factory() { return new JobDefinitionService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: JobDefinitionService, providedIn: "root" });
    JobDefinitionService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], JobDefinitionService);
    return JobDefinitionService;
}());

var NamespaceService = /** @class */ (function () {
    function NamespaceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    NamespaceService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    NamespaceService.prototype.namespaceCreateNamespace = function (namespaceCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespaceCreateRequest === null || namespaceCreateRequest === undefined) {
            throw new Error('Required parameter namespaceCreateRequest was null or undefined when calling namespaceCreateNamespace.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/namespaces", namespaceCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NamespaceService.prototype.namespaceDeleteNamespace = function (namespaceCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespaceCode === null || namespaceCode === undefined) {
            throw new Error('Required parameter namespaceCode was null or undefined when calling namespaceDeleteNamespace.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/namespaces/" + encodeURIComponent(String(namespaceCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NamespaceService.prototype.namespaceGetNamespace = function (namespaceCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespaceCode === null || namespaceCode === undefined) {
            throw new Error('Required parameter namespaceCode was null or undefined when calling namespaceGetNamespace.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/namespaces/" + encodeURIComponent(String(namespaceCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NamespaceService.prototype.namespaceGetNamespaces = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/namespaces", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NamespaceService.prototype.namespaceSearchNamespaces = function (namespaceSearchRequest, fields, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespaceSearchRequest === null || namespaceSearchRequest === undefined) {
            throw new Error('Required parameter namespaceSearchRequest was null or undefined when calling namespaceSearchNamespaces.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (fields !== undefined && fields !== null) {
            queryParameters = queryParameters.set('fields', fields);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/namespaces/search", namespaceSearchRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NamespaceService.prototype.namespaceUpdateNamespaceDefaultRecordFlag = function (namespaceCode, namespaceDefaultRecordFlagUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespaceCode === null || namespaceCode === undefined) {
            throw new Error('Required parameter namespaceCode was null or undefined when calling namespaceUpdateNamespaceDefaultRecordFlag.');
        }
        if (namespaceDefaultRecordFlagUpdateRequest === null || namespaceDefaultRecordFlagUpdateRequest === undefined) {
            throw new Error('Required parameter namespaceDefaultRecordFlagUpdateRequest was null or undefined when calling namespaceUpdateNamespaceDefaultRecordFlag.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/namespaceDefaultRecordFlag/" + encodeURIComponent(String(namespaceCode)), namespaceDefaultRecordFlagUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NamespaceService.prototype.namespaceUpdateNamespaces = function (namespaceCode, namespaceUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespaceCode === null || namespaceCode === undefined) {
            throw new Error('Required parameter namespaceCode was null or undefined when calling namespaceUpdateNamespaces.');
        }
        if (namespaceUpdateRequest === null || namespaceUpdateRequest === undefined) {
            throw new Error('Required parameter namespaceUpdateRequest was null or undefined when calling namespaceUpdateNamespaces.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/namespaces/" + encodeURIComponent(String(namespaceCode)), namespaceUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NamespaceService.ɵprov = ɵɵdefineInjectable({ factory: function NamespaceService_Factory() { return new NamespaceService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: NamespaceService, providedIn: "root" });
    NamespaceService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], NamespaceService);
    return NamespaceService;
}());

var NamespaceIAMRoleAuthorizationService = /** @class */ (function () {
    function NamespaceIAMRoleAuthorizationService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    NamespaceIAMRoleAuthorizationService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    NamespaceIAMRoleAuthorizationService.prototype.namespaceIAMRoleAuthorizationCreateNamespaceIamRoleAuthorization = function (namespaceIamRoleAuthorizationCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespaceIamRoleAuthorizationCreateRequest === null || namespaceIamRoleAuthorizationCreateRequest === undefined) {
            throw new Error('Required parameter namespaceIamRoleAuthorizationCreateRequest was null or undefined when calling namespaceIAMRoleAuthorizationCreateNamespaceIamRoleAuthorization.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/namespaceIamRoleAuthorizations", namespaceIamRoleAuthorizationCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NamespaceIAMRoleAuthorizationService.prototype.namespaceIAMRoleAuthorizationDeleteNamespaceIamRoleAuthorization = function (namespace, iamRoleName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling namespaceIAMRoleAuthorizationDeleteNamespaceIamRoleAuthorization.');
        }
        if (iamRoleName === null || iamRoleName === undefined) {
            throw new Error('Required parameter iamRoleName was null or undefined when calling namespaceIAMRoleAuthorizationDeleteNamespaceIamRoleAuthorization.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/namespaceIamRoleAuthorizations/namespaces/" + encodeURIComponent(String(namespace)) + "/iamRoleNames/" + encodeURIComponent(String(iamRoleName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NamespaceIAMRoleAuthorizationService.prototype.namespaceIAMRoleAuthorizationGetNamespaceIamRoleAuthorization = function (namespace, iamRoleName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling namespaceIAMRoleAuthorizationGetNamespaceIamRoleAuthorization.');
        }
        if (iamRoleName === null || iamRoleName === undefined) {
            throw new Error('Required parameter iamRoleName was null or undefined when calling namespaceIAMRoleAuthorizationGetNamespaceIamRoleAuthorization.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/namespaceIamRoleAuthorizations/namespaces/" + encodeURIComponent(String(namespace)) + "/iamRoleNames/" + encodeURIComponent(String(iamRoleName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NamespaceIAMRoleAuthorizationService.prototype.namespaceIAMRoleAuthorizationGetNamespaceIamRoleAuthorizations = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/namespaceIamRoleAuthorizations", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NamespaceIAMRoleAuthorizationService.prototype.namespaceIAMRoleAuthorizationGetNamespaceIamRoleAuthorizationsByIamRoleName = function (iamRoleName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (iamRoleName === null || iamRoleName === undefined) {
            throw new Error('Required parameter iamRoleName was null or undefined when calling namespaceIAMRoleAuthorizationGetNamespaceIamRoleAuthorizationsByIamRoleName.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/namespaceIamRoleAuthorizations/iamRoleNames/" + encodeURIComponent(String(iamRoleName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NamespaceIAMRoleAuthorizationService.prototype.namespaceIAMRoleAuthorizationGetNamespaceIamRoleAuthorizationsByNamespace = function (namespace, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling namespaceIAMRoleAuthorizationGetNamespaceIamRoleAuthorizationsByNamespace.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/namespaceIamRoleAuthorizations/namespaces/" + encodeURIComponent(String(namespace)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NamespaceIAMRoleAuthorizationService.prototype.namespaceIAMRoleAuthorizationUpdateNamespaceIamRoleAuthorization = function (namespace, iamRoleName, namespaceIamRoleAuthorizationUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling namespaceIAMRoleAuthorizationUpdateNamespaceIamRoleAuthorization.');
        }
        if (iamRoleName === null || iamRoleName === undefined) {
            throw new Error('Required parameter iamRoleName was null or undefined when calling namespaceIAMRoleAuthorizationUpdateNamespaceIamRoleAuthorization.');
        }
        if (namespaceIamRoleAuthorizationUpdateRequest === null || namespaceIamRoleAuthorizationUpdateRequest === undefined) {
            throw new Error('Required parameter namespaceIamRoleAuthorizationUpdateRequest was null or undefined when calling namespaceIAMRoleAuthorizationUpdateNamespaceIamRoleAuthorization.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/namespaceIamRoleAuthorizations/namespaces/" + encodeURIComponent(String(namespace)) + "/iamRoleNames/" + encodeURIComponent(String(iamRoleName)), namespaceIamRoleAuthorizationUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NamespaceIAMRoleAuthorizationService.ɵprov = ɵɵdefineInjectable({ factory: function NamespaceIAMRoleAuthorizationService_Factory() { return new NamespaceIAMRoleAuthorizationService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: NamespaceIAMRoleAuthorizationService, providedIn: "root" });
    NamespaceIAMRoleAuthorizationService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], NamespaceIAMRoleAuthorizationService);
    return NamespaceIAMRoleAuthorizationService;
}());

var NotificationRegistrationStatusService = /** @class */ (function () {
    function NotificationRegistrationStatusService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    NotificationRegistrationStatusService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    NotificationRegistrationStatusService.prototype.notificationRegistrationStatusUpdateNotificationRegistrationStatus = function (namespace, notificationName, notificationRegistrationStatusUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling notificationRegistrationStatusUpdateNotificationRegistrationStatus.');
        }
        if (notificationName === null || notificationName === undefined) {
            throw new Error('Required parameter notificationName was null or undefined when calling notificationRegistrationStatusUpdateNotificationRegistrationStatus.');
        }
        if (notificationRegistrationStatusUpdateRequest === null || notificationRegistrationStatusUpdateRequest === undefined) {
            throw new Error('Required parameter notificationRegistrationStatusUpdateRequest was null or undefined when calling notificationRegistrationStatusUpdateNotificationRegistrationStatus.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/notificationRegistrationStatus/namespaces/" + encodeURIComponent(String(namespace)) + "/notificationNames/" + encodeURIComponent(String(notificationName)), notificationRegistrationStatusUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    NotificationRegistrationStatusService.ɵprov = ɵɵdefineInjectable({ factory: function NotificationRegistrationStatusService_Factory() { return new NotificationRegistrationStatusService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: NotificationRegistrationStatusService, providedIn: "root" });
    NotificationRegistrationStatusService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], NotificationRegistrationStatusService);
    return NotificationRegistrationStatusService;
}());

var PartitionKeyGroupService = /** @class */ (function () {
    function PartitionKeyGroupService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    PartitionKeyGroupService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    PartitionKeyGroupService.prototype.partitionKeyGroupCreatePartitionKeyGroup = function (partitionKeyGroupCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (partitionKeyGroupCreateRequest === null || partitionKeyGroupCreateRequest === undefined) {
            throw new Error('Required parameter partitionKeyGroupCreateRequest was null or undefined when calling partitionKeyGroupCreatePartitionKeyGroup.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/partitionKeyGroups", partitionKeyGroupCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    PartitionKeyGroupService.prototype.partitionKeyGroupDeletePartitionKeyGroup = function (partitionKeyGroupName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (partitionKeyGroupName === null || partitionKeyGroupName === undefined) {
            throw new Error('Required parameter partitionKeyGroupName was null or undefined when calling partitionKeyGroupDeletePartitionKeyGroup.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/partitionKeyGroups/" + encodeURIComponent(String(partitionKeyGroupName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    PartitionKeyGroupService.prototype.partitionKeyGroupGetPartitionKeyGroup = function (partitionKeyGroupName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (partitionKeyGroupName === null || partitionKeyGroupName === undefined) {
            throw new Error('Required parameter partitionKeyGroupName was null or undefined when calling partitionKeyGroupGetPartitionKeyGroup.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/partitionKeyGroups/" + encodeURIComponent(String(partitionKeyGroupName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    PartitionKeyGroupService.prototype.partitionKeyGroupGetPartitionKeyGroups = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/partitionKeyGroups", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    PartitionKeyGroupService.ɵprov = ɵɵdefineInjectable({ factory: function PartitionKeyGroupService_Factory() { return new PartitionKeyGroupService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: PartitionKeyGroupService, providedIn: "root" });
    PartitionKeyGroupService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], PartitionKeyGroupService);
    return PartitionKeyGroupService;
}());

var PublishingFrequencyService = /** @class */ (function () {
    function PublishingFrequencyService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    PublishingFrequencyService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    PublishingFrequencyService.prototype.publishingFrequencyGetPublishingFrequencies = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/publishingFrequencies", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    PublishingFrequencyService.ɵprov = ɵɵdefineInjectable({ factory: function PublishingFrequencyService_Factory() { return new PublishingFrequencyService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: PublishingFrequencyService, providedIn: "root" });
    PublishingFrequencyService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], PublishingFrequencyService);
    return PublishingFrequencyService;
}());

var RecordGroupService = /** @class */ (function () {
    function RecordGroupService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    RecordGroupService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    RecordGroupService.prototype.recordGroupCreateRecordGroup = function (recordGroupCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (recordGroupCreateRequest === null || recordGroupCreateRequest === undefined) {
            throw new Error('Required parameter recordGroupCreateRequest was null or undefined when calling recordGroupCreateRecordGroup.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/recordGroups", recordGroupCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RecordGroupService.prototype.recordGroupDeleteRecordGroup = function (recordCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (recordCode === null || recordCode === undefined) {
            throw new Error('Required parameter recordCode was null or undefined when calling recordGroupDeleteRecordGroup.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/recordGroups/" + encodeURIComponent(String(recordCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RecordGroupService.prototype.recordGroupGetRecordGroup = function (recordCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (recordCode === null || recordCode === undefined) {
            throw new Error('Required parameter recordCode was null or undefined when calling recordGroupGetRecordGroup.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/recordGroups/" + encodeURIComponent(String(recordCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RecordGroupService.prototype.recordGroupGetRecordGroups = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/recordGroups", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RecordGroupService.ɵprov = ɵɵdefineInjectable({ factory: function RecordGroupService_Factory() { return new RecordGroupService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: RecordGroupService, providedIn: "root" });
    RecordGroupService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], RecordGroupService);
    return RecordGroupService;
}());

var RelationalTableRegistrationService = /** @class */ (function () {
    function RelationalTableRegistrationService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    RelationalTableRegistrationService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    RelationalTableRegistrationService.prototype.relationalTableRegistrationCreateRelationalTableRegistration = function (relationalTableRegistrationCreateRequest, appendToExistingBusinessObjectDefinition, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (relationalTableRegistrationCreateRequest === null || relationalTableRegistrationCreateRequest === undefined) {
            throw new Error('Required parameter relationalTableRegistrationCreateRequest was null or undefined when calling relationalTableRegistrationCreateRelationalTableRegistration.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (appendToExistingBusinessObjectDefinition !== undefined && appendToExistingBusinessObjectDefinition !== null) {
            queryParameters = queryParameters.set('appendToExistingBusinessObjectDefinition', appendToExistingBusinessObjectDefinition);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/relationalTableRegistrations", relationalTableRegistrationCreateRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RelationalTableRegistrationService.prototype.relationalTableRegistrationDeleteRelationalTableRegistration = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling relationalTableRegistrationDeleteRelationalTableRegistration.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling relationalTableRegistrationDeleteRelationalTableRegistration.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling relationalTableRegistrationDeleteRelationalTableRegistration.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/relationalTableRegistrations/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RelationalTableRegistrationService.ɵprov = ɵɵdefineInjectable({ factory: function RelationalTableRegistrationService_Factory() { return new RelationalTableRegistrationService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: RelationalTableRegistrationService, providedIn: "root" });
    RelationalTableRegistrationService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], RelationalTableRegistrationService);
    return RelationalTableRegistrationService;
}());

var SearchIndexService = /** @class */ (function () {
    function SearchIndexService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    SearchIndexService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    SearchIndexService.prototype.searchIndexCreateSearchIndex = function (searchIndexCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (searchIndexCreateRequest === null || searchIndexCreateRequest === undefined) {
            throw new Error('Required parameter searchIndexCreateRequest was null or undefined when calling searchIndexCreateSearchIndex.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/searchIndexes", searchIndexCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SearchIndexService.prototype.searchIndexDeleteSearchIndex = function (searchIndexName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (searchIndexName === null || searchIndexName === undefined) {
            throw new Error('Required parameter searchIndexName was null or undefined when calling searchIndexDeleteSearchIndex.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/searchIndexes/" + encodeURIComponent(String(searchIndexName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SearchIndexService.prototype.searchIndexGetSearchIndex = function (searchIndexName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (searchIndexName === null || searchIndexName === undefined) {
            throw new Error('Required parameter searchIndexName was null or undefined when calling searchIndexGetSearchIndex.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/searchIndexes/" + encodeURIComponent(String(searchIndexName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SearchIndexService.prototype.searchIndexGetSearchIndexes = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/searchIndexes", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SearchIndexService.ɵprov = ɵɵdefineInjectable({ factory: function SearchIndexService_Factory() { return new SearchIndexService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: SearchIndexService, providedIn: "root" });
    SearchIndexService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], SearchIndexService);
    return SearchIndexService;
}());

var SearchIndexActivationService = /** @class */ (function () {
    function SearchIndexActivationService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    SearchIndexActivationService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    SearchIndexActivationService.prototype.searchIndexActivationCreateSearchIndexActivation = function (searchIndexActivationCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (searchIndexActivationCreateRequest === null || searchIndexActivationCreateRequest === undefined) {
            throw new Error('Required parameter searchIndexActivationCreateRequest was null or undefined when calling searchIndexActivationCreateSearchIndexActivation.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/searchIndexActivations", searchIndexActivationCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SearchIndexActivationService.ɵprov = ɵɵdefineInjectable({ factory: function SearchIndexActivationService_Factory() { return new SearchIndexActivationService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: SearchIndexActivationService, providedIn: "root" });
    SearchIndexActivationService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], SearchIndexActivationService);
    return SearchIndexActivationService;
}());

var SecurityFunctionService = /** @class */ (function () {
    function SecurityFunctionService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    SecurityFunctionService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    SecurityFunctionService.prototype.securityFunctionCreateSecurityFunction = function (securityFunctionCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (securityFunctionCreateRequest === null || securityFunctionCreateRequest === undefined) {
            throw new Error('Required parameter securityFunctionCreateRequest was null or undefined when calling securityFunctionCreateSecurityFunction.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/securityFunctions", securityFunctionCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityFunctionService.prototype.securityFunctionDeleteSecurityFunction = function (securityFunctionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (securityFunctionName === null || securityFunctionName === undefined) {
            throw new Error('Required parameter securityFunctionName was null or undefined when calling securityFunctionDeleteSecurityFunction.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/securityFunctions/" + encodeURIComponent(String(securityFunctionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityFunctionService.prototype.securityFunctionGetSecurityFunction = function (securityFunctionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (securityFunctionName === null || securityFunctionName === undefined) {
            throw new Error('Required parameter securityFunctionName was null or undefined when calling securityFunctionGetSecurityFunction.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/securityFunctions/" + encodeURIComponent(String(securityFunctionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityFunctionService.prototype.securityFunctionGetSecurityFunctions = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/securityFunctions", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityFunctionService.ɵprov = ɵɵdefineInjectable({ factory: function SecurityFunctionService_Factory() { return new SecurityFunctionService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: SecurityFunctionService, providedIn: "root" });
    SecurityFunctionService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], SecurityFunctionService);
    return SecurityFunctionService;
}());

var SecurityRoleService = /** @class */ (function () {
    function SecurityRoleService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    SecurityRoleService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    SecurityRoleService.prototype.securityRoleCreateSecurityRole = function (securityRoleCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (securityRoleCreateRequest === null || securityRoleCreateRequest === undefined) {
            throw new Error('Required parameter securityRoleCreateRequest was null or undefined when calling securityRoleCreateSecurityRole.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/securityRoles", securityRoleCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityRoleService.prototype.securityRoleDeleteSecurityRole = function (securityRoleName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (securityRoleName === null || securityRoleName === undefined) {
            throw new Error('Required parameter securityRoleName was null or undefined when calling securityRoleDeleteSecurityRole.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/securityRoles/" + encodeURIComponent(String(securityRoleName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityRoleService.prototype.securityRoleGetSecurityRole = function (securityRoleName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (securityRoleName === null || securityRoleName === undefined) {
            throw new Error('Required parameter securityRoleName was null or undefined when calling securityRoleGetSecurityRole.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/securityRoles/" + encodeURIComponent(String(securityRoleName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityRoleService.prototype.securityRoleGetSecurityRoles = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/securityRoles", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityRoleService.prototype.securityRoleUpdateSecurityRole = function (securityRoleName, securityRoleUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (securityRoleName === null || securityRoleName === undefined) {
            throw new Error('Required parameter securityRoleName was null or undefined when calling securityRoleUpdateSecurityRole.');
        }
        if (securityRoleUpdateRequest === null || securityRoleUpdateRequest === undefined) {
            throw new Error('Required parameter securityRoleUpdateRequest was null or undefined when calling securityRoleUpdateSecurityRole.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/securityRoles/" + encodeURIComponent(String(securityRoleName)), securityRoleUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityRoleService.ɵprov = ɵɵdefineInjectable({ factory: function SecurityRoleService_Factory() { return new SecurityRoleService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: SecurityRoleService, providedIn: "root" });
    SecurityRoleService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], SecurityRoleService);
    return SecurityRoleService;
}());

var SecurityRoleToFunctionMappingService = /** @class */ (function () {
    function SecurityRoleToFunctionMappingService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    SecurityRoleToFunctionMappingService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    SecurityRoleToFunctionMappingService.prototype.securityRoleToFunctionMappingCreateSecurityRoleFunction = function (securityRoleFunctionCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (securityRoleFunctionCreateRequest === null || securityRoleFunctionCreateRequest === undefined) {
            throw new Error('Required parameter securityRoleFunctionCreateRequest was null or undefined when calling securityRoleToFunctionMappingCreateSecurityRoleFunction.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/securityRoleFunctions", securityRoleFunctionCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityRoleToFunctionMappingService.prototype.securityRoleToFunctionMappingDeleteSecurityRoleFunction = function (securityRoleName, securityFunctionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (securityRoleName === null || securityRoleName === undefined) {
            throw new Error('Required parameter securityRoleName was null or undefined when calling securityRoleToFunctionMappingDeleteSecurityRoleFunction.');
        }
        if (securityFunctionName === null || securityFunctionName === undefined) {
            throw new Error('Required parameter securityFunctionName was null or undefined when calling securityRoleToFunctionMappingDeleteSecurityRoleFunction.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/securityRoleFunctions/securityRoleNames/" + encodeURIComponent(String(securityRoleName)) + "/securityFunctionNames/" + encodeURIComponent(String(securityFunctionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityRoleToFunctionMappingService.prototype.securityRoleToFunctionMappingGetSecurityRoleFunction = function (securityRoleName, securityFunctionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (securityRoleName === null || securityRoleName === undefined) {
            throw new Error('Required parameter securityRoleName was null or undefined when calling securityRoleToFunctionMappingGetSecurityRoleFunction.');
        }
        if (securityFunctionName === null || securityFunctionName === undefined) {
            throw new Error('Required parameter securityFunctionName was null or undefined when calling securityRoleToFunctionMappingGetSecurityRoleFunction.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/securityRoleFunctions/securityRoleNames/" + encodeURIComponent(String(securityRoleName)) + "/securityFunctionNames/" + encodeURIComponent(String(securityFunctionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityRoleToFunctionMappingService.prototype.securityRoleToFunctionMappingGetSecurityRoleFunctions = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/securityRoleFunctions", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityRoleToFunctionMappingService.prototype.securityRoleToFunctionMappingGetSecurityRoleFunctionsBySecurityFunction = function (securityFunctionName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (securityFunctionName === null || securityFunctionName === undefined) {
            throw new Error('Required parameter securityFunctionName was null or undefined when calling securityRoleToFunctionMappingGetSecurityRoleFunctionsBySecurityFunction.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/securityRoleFunctions/securityFunctionNames/" + encodeURIComponent(String(securityFunctionName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityRoleToFunctionMappingService.prototype.securityRoleToFunctionMappingGetSecurityRoleFunctionsBySecurityRole = function (securityRoleName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (securityRoleName === null || securityRoleName === undefined) {
            throw new Error('Required parameter securityRoleName was null or undefined when calling securityRoleToFunctionMappingGetSecurityRoleFunctionsBySecurityRole.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/securityRoleFunctions/securityRoleNames/" + encodeURIComponent(String(securityRoleName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SecurityRoleToFunctionMappingService.ɵprov = ɵɵdefineInjectable({ factory: function SecurityRoleToFunctionMappingService_Factory() { return new SecurityRoleToFunctionMappingService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: SecurityRoleToFunctionMappingService, providedIn: "root" });
    SecurityRoleToFunctionMappingService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], SecurityRoleToFunctionMappingService);
    return SecurityRoleToFunctionMappingService;
}());

var StorageService = /** @class */ (function () {
    function StorageService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    StorageService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    StorageService.prototype.storageCreateStorage = function (storageCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (storageCreateRequest === null || storageCreateRequest === undefined) {
            throw new Error('Required parameter storageCreateRequest was null or undefined when calling storageCreateStorage.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/storages", storageCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StorageService.prototype.storageDeleteStorage = function (storageName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (storageName === null || storageName === undefined) {
            throw new Error('Required parameter storageName was null or undefined when calling storageDeleteStorage.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/storages/" + encodeURIComponent(String(storageName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StorageService.prototype.storageGetStorage = function (storageName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (storageName === null || storageName === undefined) {
            throw new Error('Required parameter storageName was null or undefined when calling storageGetStorage.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/storages/" + encodeURIComponent(String(storageName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StorageService.prototype.storageGetStorages = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/storages", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StorageService.prototype.storageUpdateStorage = function (storageName, storageUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (storageName === null || storageName === undefined) {
            throw new Error('Required parameter storageName was null or undefined when calling storageUpdateStorage.');
        }
        if (storageUpdateRequest === null || storageUpdateRequest === undefined) {
            throw new Error('Required parameter storageUpdateRequest was null or undefined when calling storageUpdateStorage.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/storages/" + encodeURIComponent(String(storageName)), storageUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StorageService.prototype.storageUpdateStorageAttributes = function (storageName, storageAttributesUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (storageName === null || storageName === undefined) {
            throw new Error('Required parameter storageName was null or undefined when calling storageUpdateStorageAttributes.');
        }
        if (storageAttributesUpdateRequest === null || storageAttributesUpdateRequest === undefined) {
            throw new Error('Required parameter storageAttributesUpdateRequest was null or undefined when calling storageUpdateStorageAttributes.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/storageAttributes/storages/" + encodeURIComponent(String(storageName)), storageAttributesUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StorageService.ɵprov = ɵɵdefineInjectable({ factory: function StorageService_Factory() { return new StorageService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: StorageService, providedIn: "root" });
    StorageService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], StorageService);
    return StorageService;
}());

var StoragePlatformService = /** @class */ (function () {
    function StoragePlatformService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    StoragePlatformService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    StoragePlatformService.prototype.storagePlatformGetStoragePlatform = function (name, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (name === null || name === undefined) {
            throw new Error('Required parameter name was null or undefined when calling storagePlatformGetStoragePlatform.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/storagePlatforms/" + encodeURIComponent(String(name)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StoragePlatformService.prototype.storagePlatformGetStoragePlatforms = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/storagePlatforms", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StoragePlatformService.ɵprov = ɵɵdefineInjectable({ factory: function StoragePlatformService_Factory() { return new StoragePlatformService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: StoragePlatformService, providedIn: "root" });
    StoragePlatformService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], StoragePlatformService);
    return StoragePlatformService;
}());

var StoragePolicyService = /** @class */ (function () {
    function StoragePolicyService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    StoragePolicyService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    StoragePolicyService.prototype.storagePolicyCreateStoragePolicy = function (storagePolicyCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (storagePolicyCreateRequest === null || storagePolicyCreateRequest === undefined) {
            throw new Error('Required parameter storagePolicyCreateRequest was null or undefined when calling storagePolicyCreateStoragePolicy.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/storagePolicies", storagePolicyCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StoragePolicyService.prototype.storagePolicyDeleteStoragePolicy = function (namespace, storagePolicyName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling storagePolicyDeleteStoragePolicy.');
        }
        if (storagePolicyName === null || storagePolicyName === undefined) {
            throw new Error('Required parameter storagePolicyName was null or undefined when calling storagePolicyDeleteStoragePolicy.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/storagePolicies/namespaces/" + encodeURIComponent(String(namespace)) + "/storagePolicyNames/" + encodeURIComponent(String(storagePolicyName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StoragePolicyService.prototype.storagePolicyGetStoragePolicy = function (namespace, storagePolicyName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling storagePolicyGetStoragePolicy.');
        }
        if (storagePolicyName === null || storagePolicyName === undefined) {
            throw new Error('Required parameter storagePolicyName was null or undefined when calling storagePolicyGetStoragePolicy.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/storagePolicies/namespaces/" + encodeURIComponent(String(namespace)) + "/storagePolicyNames/" + encodeURIComponent(String(storagePolicyName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StoragePolicyService.prototype.storagePolicyGetStoragePolicyKeys = function (namespace, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling storagePolicyGetStoragePolicyKeys.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/storagePolicies/namespaces/" + encodeURIComponent(String(namespace)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StoragePolicyService.prototype.storagePolicySearchStoragePolicies = function (storagePolicySearchRequest, fields, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (storagePolicySearchRequest === null || storagePolicySearchRequest === undefined) {
            throw new Error('Required parameter storagePolicySearchRequest was null or undefined when calling storagePolicySearchStoragePolicies.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (fields !== undefined && fields !== null) {
            queryParameters = queryParameters.set('fields', fields);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/storagePolicies/search", storagePolicySearchRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StoragePolicyService.prototype.storagePolicyUpdateStoragePolicy = function (namespace, storagePolicyName, storagePolicyUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling storagePolicyUpdateStoragePolicy.');
        }
        if (storagePolicyName === null || storagePolicyName === undefined) {
            throw new Error('Required parameter storagePolicyName was null or undefined when calling storagePolicyUpdateStoragePolicy.');
        }
        if (storagePolicyUpdateRequest === null || storagePolicyUpdateRequest === undefined) {
            throw new Error('Required parameter storagePolicyUpdateRequest was null or undefined when calling storagePolicyUpdateStoragePolicy.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/storagePolicies/namespaces/" + encodeURIComponent(String(namespace)) + "/storagePolicyNames/" + encodeURIComponent(String(storagePolicyName)), storagePolicyUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StoragePolicyService.ɵprov = ɵɵdefineInjectable({ factory: function StoragePolicyService_Factory() { return new StoragePolicyService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: StoragePolicyService, providedIn: "root" });
    StoragePolicyService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], StoragePolicyService);
    return StoragePolicyService;
}());

var StorageUnitService = /** @class */ (function () {
    function StorageUnitService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    StorageUnitService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    StorageUnitService.prototype.storageUnitGetStorageUnitDownloadCredential = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, storageName, subPartitionValues, allowedSourceIpAddresses, allowedSourceVpcEndpoints, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling storageUnitGetStorageUnitDownloadCredential.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling storageUnitGetStorageUnitDownloadCredential.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling storageUnitGetStorageUnitDownloadCredential.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling storageUnitGetStorageUnitDownloadCredential.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling storageUnitGetStorageUnitDownloadCredential.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling storageUnitGetStorageUnitDownloadCredential.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling storageUnitGetStorageUnitDownloadCredential.');
        }
        if (storageName === null || storageName === undefined) {
            throw new Error('Required parameter storageName was null or undefined when calling storageUnitGetStorageUnitDownloadCredential.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (subPartitionValues !== undefined && subPartitionValues !== null) {
            queryParameters = queryParameters.set('subPartitionValues', subPartitionValues);
        }
        if (allowedSourceIpAddresses !== undefined && allowedSourceIpAddresses !== null) {
            queryParameters = queryParameters.set('allowedSourceIpAddresses', allowedSourceIpAddresses);
        }
        if (allowedSourceVpcEndpoints !== undefined && allowedSourceVpcEndpoints !== null) {
            queryParameters = queryParameters.set('allowedSourceVpcEndpoints', allowedSourceVpcEndpoints);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/storageUnits/download/credential/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/storageNames/" + encodeURIComponent(String(storageName)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StorageUnitService.prototype.storageUnitGetStorageUnitUploadCredential = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, storageName, subPartitionValues, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling storageUnitGetStorageUnitUploadCredential.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling storageUnitGetStorageUnitUploadCredential.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling storageUnitGetStorageUnitUploadCredential.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling storageUnitGetStorageUnitUploadCredential.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling storageUnitGetStorageUnitUploadCredential.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling storageUnitGetStorageUnitUploadCredential.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling storageUnitGetStorageUnitUploadCredential.');
        }
        if (storageName === null || storageName === undefined) {
            throw new Error('Required parameter storageName was null or undefined when calling storageUnitGetStorageUnitUploadCredential.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (subPartitionValues !== undefined && subPartitionValues !== null) {
            queryParameters = queryParameters.set('subPartitionValues', subPartitionValues);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/storageUnits/upload/credential/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)) + "/storageNames/" + encodeURIComponent(String(storageName)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StorageUnitService.ɵprov = ɵɵdefineInjectable({ factory: function StorageUnitService_Factory() { return new StorageUnitService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: StorageUnitService, providedIn: "root" });
    StorageUnitService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], StorageUnitService);
    return StorageUnitService;
}());

var StorageUnitNotificationRegistrationService = /** @class */ (function () {
    function StorageUnitNotificationRegistrationService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    StorageUnitNotificationRegistrationService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    StorageUnitNotificationRegistrationService.prototype.storageUnitNotificationRegistrationCreateStorageUnitNotificationRegistration = function (storageUnitNotificationRegistrationCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (storageUnitNotificationRegistrationCreateRequest === null || storageUnitNotificationRegistrationCreateRequest === undefined) {
            throw new Error('Required parameter storageUnitNotificationRegistrationCreateRequest was null or undefined when calling storageUnitNotificationRegistrationCreateStorageUnitNotificationRegistration.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/notificationRegistrations/storageUnitNotificationRegistrations", storageUnitNotificationRegistrationCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StorageUnitNotificationRegistrationService.prototype.storageUnitNotificationRegistrationDeleteStorageUnitNotification = function (namespace, notificationName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling storageUnitNotificationRegistrationDeleteStorageUnitNotification.');
        }
        if (notificationName === null || notificationName === undefined) {
            throw new Error('Required parameter notificationName was null or undefined when calling storageUnitNotificationRegistrationDeleteStorageUnitNotification.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/notificationRegistrations/storageUnitNotificationRegistrations/namespaces/" + encodeURIComponent(String(namespace)) + "/notificationNames/" + encodeURIComponent(String(notificationName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StorageUnitNotificationRegistrationService.prototype.storageUnitNotificationRegistrationGetStorageUnitNotificationRegistration = function (namespace, notificationName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling storageUnitNotificationRegistrationGetStorageUnitNotificationRegistration.');
        }
        if (notificationName === null || notificationName === undefined) {
            throw new Error('Required parameter notificationName was null or undefined when calling storageUnitNotificationRegistrationGetStorageUnitNotificationRegistration.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/notificationRegistrations/storageUnitNotificationRegistrations/namespaces/" + encodeURIComponent(String(namespace)) + "/notificationNames/" + encodeURIComponent(String(notificationName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StorageUnitNotificationRegistrationService.prototype.storageUnitNotificationRegistrationGetStorageUnitNotificationRegistrationsByNamespace = function (namespace, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling storageUnitNotificationRegistrationGetStorageUnitNotificationRegistrationsByNamespace.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/notificationRegistrations/storageUnitNotificationRegistrations/namespaces/" + encodeURIComponent(String(namespace)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StorageUnitNotificationRegistrationService.prototype.storageUnitNotificationRegistrationGetStorageUnitNotificationRegistrationsByNotificationFilter = function (businessObjectDefinitionNamespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (businessObjectDefinitionNamespace === null || businessObjectDefinitionNamespace === undefined) {
            throw new Error('Required parameter businessObjectDefinitionNamespace was null or undefined when calling storageUnitNotificationRegistrationGetStorageUnitNotificationRegistrationsByNotificationFilter.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling storageUnitNotificationRegistrationGetStorageUnitNotificationRegistrationsByNotificationFilter.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (businessObjectDefinitionNamespace !== undefined && businessObjectDefinitionNamespace !== null) {
            queryParameters = queryParameters.set('businessObjectDefinitionNamespace', businessObjectDefinitionNamespace);
        }
        if (businessObjectDefinitionName !== undefined && businessObjectDefinitionName !== null) {
            queryParameters = queryParameters.set('businessObjectDefinitionName', businessObjectDefinitionName);
        }
        if (businessObjectFormatUsage !== undefined && businessObjectFormatUsage !== null) {
            queryParameters = queryParameters.set('businessObjectFormatUsage', businessObjectFormatUsage);
        }
        if (businessObjectFormatFileType !== undefined && businessObjectFormatFileType !== null) {
            queryParameters = queryParameters.set('businessObjectFormatFileType', businessObjectFormatFileType);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/notificationRegistrations/storageUnitNotificationRegistrations", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StorageUnitNotificationRegistrationService.prototype.storageUnitNotificationRegistrationUpdateStorageUnitNotificationRegistration = function (namespace, notificationName, storageUnitNotificationRegistrationUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling storageUnitNotificationRegistrationUpdateStorageUnitNotificationRegistration.');
        }
        if (notificationName === null || notificationName === undefined) {
            throw new Error('Required parameter notificationName was null or undefined when calling storageUnitNotificationRegistrationUpdateStorageUnitNotificationRegistration.');
        }
        if (storageUnitNotificationRegistrationUpdateRequest === null || storageUnitNotificationRegistrationUpdateRequest === undefined) {
            throw new Error('Required parameter storageUnitNotificationRegistrationUpdateRequest was null or undefined when calling storageUnitNotificationRegistrationUpdateStorageUnitNotificationRegistration.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/notificationRegistrations/storageUnitNotificationRegistrations/namespaces/" + encodeURIComponent(String(namespace)) + "/notificationNames/" + encodeURIComponent(String(notificationName)), storageUnitNotificationRegistrationUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    StorageUnitNotificationRegistrationService.ɵprov = ɵɵdefineInjectable({ factory: function StorageUnitNotificationRegistrationService_Factory() { return new StorageUnitNotificationRegistrationService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: StorageUnitNotificationRegistrationService, providedIn: "root" });
    StorageUnitNotificationRegistrationService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], StorageUnitNotificationRegistrationService);
    return StorageUnitNotificationRegistrationService;
}());

var SubjectMatterExpertService = /** @class */ (function () {
    function SubjectMatterExpertService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    SubjectMatterExpertService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    SubjectMatterExpertService.prototype.subjectMatterExpertGetSubjectMatterExpert = function (userId, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling subjectMatterExpertGetSubjectMatterExpert.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/subjectMatterExperts/" + encodeURIComponent(String(userId)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SubjectMatterExpertService.ɵprov = ɵɵdefineInjectable({ factory: function SubjectMatterExpertService_Factory() { return new SubjectMatterExpertService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: SubjectMatterExpertService, providedIn: "root" });
    SubjectMatterExpertService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], SubjectMatterExpertService);
    return SubjectMatterExpertService;
}());

var SystemJobService = /** @class */ (function () {
    function SystemJobService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    SystemJobService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    SystemJobService.prototype.systemJobRunSystemJob = function (systemJobRunRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (systemJobRunRequest === null || systemJobRunRequest === undefined) {
            throw new Error('Required parameter systemJobRunRequest was null or undefined when calling systemJobRunSystemJob.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/systemJobs", systemJobRunRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    SystemJobService.ɵprov = ɵɵdefineInjectable({ factory: function SystemJobService_Factory() { return new SystemJobService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: SystemJobService, providedIn: "root" });
    SystemJobService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], SystemJobService);
    return SystemJobService;
}());

var TagService = /** @class */ (function () {
    function TagService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    TagService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    TagService.prototype.tagCreateTag = function (tagCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (tagCreateRequest === null || tagCreateRequest === undefined) {
            throw new Error('Required parameter tagCreateRequest was null or undefined when calling tagCreateTag.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/tags", tagCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TagService.prototype.tagDeleteTag = function (tagTypeCode, tagCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (tagTypeCode === null || tagTypeCode === undefined) {
            throw new Error('Required parameter tagTypeCode was null or undefined when calling tagDeleteTag.');
        }
        if (tagCode === null || tagCode === undefined) {
            throw new Error('Required parameter tagCode was null or undefined when calling tagDeleteTag.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/tags/tagTypes/" + encodeURIComponent(String(tagTypeCode)) + "/tagCodes/" + encodeURIComponent(String(tagCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TagService.prototype.tagGetTag = function (tagTypeCode, tagCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (tagTypeCode === null || tagTypeCode === undefined) {
            throw new Error('Required parameter tagTypeCode was null or undefined when calling tagGetTag.');
        }
        if (tagCode === null || tagCode === undefined) {
            throw new Error('Required parameter tagCode was null or undefined when calling tagGetTag.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/tags/tagTypes/" + encodeURIComponent(String(tagTypeCode)) + "/tagCodes/" + encodeURIComponent(String(tagCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TagService.prototype.tagGetTags = function (tagTypeCode, tagCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (tagTypeCode === null || tagTypeCode === undefined) {
            throw new Error('Required parameter tagTypeCode was null or undefined when calling tagGetTags.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (tagCode !== undefined && tagCode !== null) {
            queryParameters = queryParameters.set('tagCode', tagCode);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/tags/tagTypes/" + encodeURIComponent(String(tagTypeCode)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TagService.prototype.tagSearchTags = function (tagSearchRequest, fields, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (tagSearchRequest === null || tagSearchRequest === undefined) {
            throw new Error('Required parameter tagSearchRequest was null or undefined when calling tagSearchTags.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (fields !== undefined && fields !== null) {
            queryParameters = queryParameters.set('fields', fields);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/tags/search", tagSearchRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TagService.prototype.tagUpdateTag = function (tagTypeCode, tagCode, tagUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (tagTypeCode === null || tagTypeCode === undefined) {
            throw new Error('Required parameter tagTypeCode was null or undefined when calling tagUpdateTag.');
        }
        if (tagCode === null || tagCode === undefined) {
            throw new Error('Required parameter tagCode was null or undefined when calling tagUpdateTag.');
        }
        if (tagUpdateRequest === null || tagUpdateRequest === undefined) {
            throw new Error('Required parameter tagUpdateRequest was null or undefined when calling tagUpdateTag.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/tags/tagTypes/" + encodeURIComponent(String(tagTypeCode)) + "/tagCodes/" + encodeURIComponent(String(tagCode)), tagUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TagService.ɵprov = ɵɵdefineInjectable({ factory: function TagService_Factory() { return new TagService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: TagService, providedIn: "root" });
    TagService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], TagService);
    return TagService;
}());

var TagTypeService = /** @class */ (function () {
    function TagTypeService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    TagTypeService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    TagTypeService.prototype.tagTypeCreateTagType = function (tagTypeCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (tagTypeCreateRequest === null || tagTypeCreateRequest === undefined) {
            throw new Error('Required parameter tagTypeCreateRequest was null or undefined when calling tagTypeCreateTagType.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/tagTypes", tagTypeCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TagTypeService.prototype.tagTypeDeleteTagType = function (tagTypeCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (tagTypeCode === null || tagTypeCode === undefined) {
            throw new Error('Required parameter tagTypeCode was null or undefined when calling tagTypeDeleteTagType.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/tagTypes/" + encodeURIComponent(String(tagTypeCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TagTypeService.prototype.tagTypeGetTagType = function (tagTypeCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (tagTypeCode === null || tagTypeCode === undefined) {
            throw new Error('Required parameter tagTypeCode was null or undefined when calling tagTypeGetTagType.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/tagTypes/" + encodeURIComponent(String(tagTypeCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TagTypeService.prototype.tagTypeGetTagTypes = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/tagTypes", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TagTypeService.prototype.tagTypeSearchTagTypes = function (tagTypeSearchRequest, fields, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (tagTypeSearchRequest === null || tagTypeSearchRequest === undefined) {
            throw new Error('Required parameter tagTypeSearchRequest was null or undefined when calling tagTypeSearchTagTypes.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (fields !== undefined && fields !== null) {
            queryParameters = queryParameters.set('fields', fields);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/tagTypes/search", tagTypeSearchRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TagTypeService.prototype.tagTypeUpdateTagType = function (tagTypeCode, tagTypeUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (tagTypeCode === null || tagTypeCode === undefined) {
            throw new Error('Required parameter tagTypeCode was null or undefined when calling tagTypeUpdateTagType.');
        }
        if (tagTypeUpdateRequest === null || tagTypeUpdateRequest === undefined) {
            throw new Error('Required parameter tagTypeUpdateRequest was null or undefined when calling tagTypeUpdateTagType.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/tagTypes/" + encodeURIComponent(String(tagTypeCode)), tagTypeUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TagTypeService.ɵprov = ɵɵdefineInjectable({ factory: function TagTypeService_Factory() { return new TagTypeService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: TagTypeService, providedIn: "root" });
    TagTypeService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], TagTypeService);
    return TagTypeService;
}());

var UploadAndDownloadService = /** @class */ (function () {
    function UploadAndDownloadService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    UploadAndDownloadService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    UploadAndDownloadService.prototype.uploadandDownloadExtendUploadSingleCredentials = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling uploadandDownloadExtendUploadSingleCredentials.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling uploadandDownloadExtendUploadSingleCredentials.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling uploadandDownloadExtendUploadSingleCredentials.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling uploadandDownloadExtendUploadSingleCredentials.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling uploadandDownloadExtendUploadSingleCredentials.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling uploadandDownloadExtendUploadSingleCredentials.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling uploadandDownloadExtendUploadSingleCredentials.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/upload/single/credential/extension/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UploadAndDownloadService.prototype.uploadandDownloadInitiateDownloadSingle = function (namespace, businessObjectDefinitionName, businessObjectFormatUsage, businessObjectFormatFileType, businessObjectFormatVersion, partitionValue, businessObjectDataVersion, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling uploadandDownloadInitiateDownloadSingle.');
        }
        if (businessObjectDefinitionName === null || businessObjectDefinitionName === undefined) {
            throw new Error('Required parameter businessObjectDefinitionName was null or undefined when calling uploadandDownloadInitiateDownloadSingle.');
        }
        if (businessObjectFormatUsage === null || businessObjectFormatUsage === undefined) {
            throw new Error('Required parameter businessObjectFormatUsage was null or undefined when calling uploadandDownloadInitiateDownloadSingle.');
        }
        if (businessObjectFormatFileType === null || businessObjectFormatFileType === undefined) {
            throw new Error('Required parameter businessObjectFormatFileType was null or undefined when calling uploadandDownloadInitiateDownloadSingle.');
        }
        if (businessObjectFormatVersion === null || businessObjectFormatVersion === undefined) {
            throw new Error('Required parameter businessObjectFormatVersion was null or undefined when calling uploadandDownloadInitiateDownloadSingle.');
        }
        if (partitionValue === null || partitionValue === undefined) {
            throw new Error('Required parameter partitionValue was null or undefined when calling uploadandDownloadInitiateDownloadSingle.');
        }
        if (businessObjectDataVersion === null || businessObjectDataVersion === undefined) {
            throw new Error('Required parameter businessObjectDataVersion was null or undefined when calling uploadandDownloadInitiateDownloadSingle.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/download/single/initiation/namespaces/" + encodeURIComponent(String(namespace)) + "/businessObjectDefinitionNames/" + encodeURIComponent(String(businessObjectDefinitionName)) + "/businessObjectFormatUsages/" + encodeURIComponent(String(businessObjectFormatUsage)) + "/businessObjectFormatFileTypes/" + encodeURIComponent(String(businessObjectFormatFileType)) + "/businessObjectFormatVersions/" + encodeURIComponent(String(businessObjectFormatVersion)) + "/partitionValues/" + encodeURIComponent(String(partitionValue)) + "/businessObjectDataVersions/" + encodeURIComponent(String(businessObjectDataVersion)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UploadAndDownloadService.prototype.uploadandDownloadInitiateDownloadSingleBusinessObjectDataStorageFile = function (downloadBusinessObjectDataStorageFileSingleInitiationRequest, preSignedUrlDurationSeconds, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (downloadBusinessObjectDataStorageFileSingleInitiationRequest === null || downloadBusinessObjectDataStorageFileSingleInitiationRequest === undefined) {
            throw new Error('Required parameter downloadBusinessObjectDataStorageFileSingleInitiationRequest was null or undefined when calling uploadandDownloadInitiateDownloadSingleBusinessObjectDataStorageFile.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (preSignedUrlDurationSeconds !== undefined && preSignedUrlDurationSeconds !== null) {
            queryParameters = queryParameters.set('preSignedUrlDurationSeconds', preSignedUrlDurationSeconds);
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/download/businessObjectDataStorageFile/single/initiation", downloadBusinessObjectDataStorageFileSingleInitiationRequest, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UploadAndDownloadService.prototype.uploadandDownloadInitiateDownloadSingleSampleFile = function (downloadBusinessObjectDefinitionSampleDataFileSingleInitiationRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (downloadBusinessObjectDefinitionSampleDataFileSingleInitiationRequest === null || downloadBusinessObjectDefinitionSampleDataFileSingleInitiationRequest === undefined) {
            throw new Error('Required parameter downloadBusinessObjectDefinitionSampleDataFileSingleInitiationRequest was null or undefined when calling uploadandDownloadInitiateDownloadSingleSampleFile.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/download/businessObjectDefinitionSampleDataFile/single/initiation", downloadBusinessObjectDefinitionSampleDataFileSingleInitiationRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UploadAndDownloadService.prototype.uploadandDownloadInitiateUploadSampleFile = function (uploadBusinessObjectDefinitionSampleDataFileInitiationRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (uploadBusinessObjectDefinitionSampleDataFileInitiationRequest === null || uploadBusinessObjectDefinitionSampleDataFileInitiationRequest === undefined) {
            throw new Error('Required parameter uploadBusinessObjectDefinitionSampleDataFileInitiationRequest was null or undefined when calling uploadandDownloadInitiateUploadSampleFile.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/upload/businessObjectDefinitionSampleDataFile/initiation", uploadBusinessObjectDefinitionSampleDataFileInitiationRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UploadAndDownloadService.prototype.uploadandDownloadInitiateUploadSingle = function (uploadSingleInitiationRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (uploadSingleInitiationRequest === null || uploadSingleInitiationRequest === undefined) {
            throw new Error('Required parameter uploadSingleInitiationRequest was null or undefined when calling uploadandDownloadInitiateUploadSingle.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/upload/single/initiation", uploadSingleInitiationRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UploadAndDownloadService.ɵprov = ɵɵdefineInjectable({ factory: function UploadAndDownloadService_Factory() { return new UploadAndDownloadService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: UploadAndDownloadService, providedIn: "root" });
    UploadAndDownloadService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], UploadAndDownloadService);
    return UploadAndDownloadService;
}());

var UserNamespaceAuthorizationService = /** @class */ (function () {
    function UserNamespaceAuthorizationService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost/herd-app/rest';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (configuration) {
            this.configuration = configuration;
            this.configuration.basePath = configuration.basePath || basePath || this.basePath;
        }
        else {
            this.configuration.basePath = basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    UserNamespaceAuthorizationService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        for (var _i = 0, consumes_1 = consumes; _i < consumes_1.length; _i++) {
            var consume = consumes_1[_i];
            if (form === consume) {
                return true;
            }
        }
        return false;
    };
    UserNamespaceAuthorizationService.prototype.userNamespaceAuthorizationCreateUserNamespaceAuthorization = function (userNamespaceAuthorizationCreateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (userNamespaceAuthorizationCreateRequest === null || userNamespaceAuthorizationCreateRequest === undefined) {
            throw new Error('Required parameter userNamespaceAuthorizationCreateRequest was null or undefined when calling userNamespaceAuthorizationCreateUserNamespaceAuthorization.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.configuration.basePath + "/userNamespaceAuthorizations", userNamespaceAuthorizationCreateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserNamespaceAuthorizationService.prototype.userNamespaceAuthorizationDeleteUserNamespaceAuthorization = function (userId, namespace, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling userNamespaceAuthorizationDeleteUserNamespaceAuthorization.');
        }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling userNamespaceAuthorizationDeleteUserNamespaceAuthorization.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/userNamespaceAuthorizations/userIds/" + encodeURIComponent(String(userId)) + "/namespaces/" + encodeURIComponent(String(namespace)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserNamespaceAuthorizationService.prototype.userNamespaceAuthorizationDeleteUserNamespaceAuthorizationsByNamespace = function (namespace, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling userNamespaceAuthorizationDeleteUserNamespaceAuthorizationsByNamespace.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/userNamespaceAuthorizations/namespaces/" + encodeURIComponent(String(namespace)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserNamespaceAuthorizationService.prototype.userNamespaceAuthorizationDeleteUserNamespaceAuthorizationsByUserId = function (userId, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling userNamespaceAuthorizationDeleteUserNamespaceAuthorizationsByUserId.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.configuration.basePath + "/userNamespaceAuthorizations/userIds/" + encodeURIComponent(String(userId)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserNamespaceAuthorizationService.prototype.userNamespaceAuthorizationGetUserNamespaceAuthorization = function (userId, namespace, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling userNamespaceAuthorizationGetUserNamespaceAuthorization.');
        }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling userNamespaceAuthorizationGetUserNamespaceAuthorization.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/userNamespaceAuthorizations/userIds/" + encodeURIComponent(String(userId)) + "/namespaces/" + encodeURIComponent(String(namespace)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserNamespaceAuthorizationService.prototype.userNamespaceAuthorizationGetUserNamespaceAuthorizationsByNamespace = function (namespace, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling userNamespaceAuthorizationGetUserNamespaceAuthorizationsByNamespace.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/userNamespaceAuthorizations/namespaces/" + encodeURIComponent(String(namespace)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserNamespaceAuthorizationService.prototype.userNamespaceAuthorizationGetUserNamespaceAuthorizationsByUserId = function (userId, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling userNamespaceAuthorizationGetUserNamespaceAuthorizationsByUserId.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.configuration.basePath + "/userNamespaceAuthorizations/userIds/" + encodeURIComponent(String(userId)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserNamespaceAuthorizationService.prototype.userNamespaceAuthorizationUpdateUserNamespaceAuthorization = function (userId, namespace, userNamespaceAuthorizationUpdateRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling userNamespaceAuthorizationUpdateUserNamespaceAuthorization.');
        }
        if (namespace === null || namespace === undefined) {
            throw new Error('Required parameter namespace was null or undefined when calling userNamespaceAuthorizationUpdateUserNamespaceAuthorization.');
        }
        if (userNamespaceAuthorizationUpdateRequest === null || userNamespaceAuthorizationUpdateRequest === undefined) {
            throw new Error('Required parameter userNamespaceAuthorizationUpdateRequest was null or undefined when calling userNamespaceAuthorizationUpdateUserNamespaceAuthorization.');
        }
        var headers = this.defaultHeaders;
        // authentication (basicAuth) required
        if (this.configuration.username || this.configuration.password) {
            headers = headers.set('Authorization', 'Basic ' + btoa(this.configuration.username + ':' + this.configuration.password));
        }
        // authentication (oauthAuth) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json',
            'application/xml'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected !== undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json',
            'application/xml'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected !== undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.configuration.basePath + "/userNamespaceAuthorizations/userIds/" + encodeURIComponent(String(userId)) + "/namespaces/" + encodeURIComponent(String(namespace)), userNamespaceAuthorizationUpdateRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserNamespaceAuthorizationService.ɵprov = ɵɵdefineInjectable({ factory: function UserNamespaceAuthorizationService_Factory() { return new UserNamespaceAuthorizationService(ɵɵinject(HttpClient), ɵɵinject(BASE_PATH, 8), ɵɵinject(Configuration, 8)); }, token: UserNamespaceAuthorizationService, providedIn: "root" });
    UserNamespaceAuthorizationService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Optional()), __param(1, Inject(BASE_PATH)), __param(2, Optional()),
        __metadata("design:paramtypes", [HttpClient, String, Configuration])
    ], UserNamespaceAuthorizationService);
    return UserNamespaceAuthorizationService;
}());

var APIS = [AllowedAttributeValueService, ApplicationService, AttributeValueListService, AvailabilityDayService, BusinessObjectDataService, BusinessObjectDataAttributeService, BusinessObjectDataNotificationRegistrationService, BusinessObjectDataStatusService, BusinessObjectDataStorageFileService, BusinessObjectDataStorageUnitService, BusinessObjectDataStorageUnitStatusService, BusinessObjectDefinitionService, BusinessObjectDefinitionColumnService, BusinessObjectDefinitionDescriptionSuggestionService, BusinessObjectDefinitionSubjectMatterExpertService, BusinessObjectDefinitionTagService, BusinessObjectFormatService, BusinessObjectFormatExternalInterfaceDescriptiveInformationService, BusinessObjectFormatToExternalInterfaceMappingService, ConfigurationEntryService, CurrentUserService, CustomDDLService, DataProviderService, DepartmentService, EMRService, EMRClusterDefinitionService, ExpectedPartitionValueService, ExternalInterfaceService, FileTypeService, GlobalAttributeDefinitionService, IndexSearchService, JobService, JobDefinitionService, NamespaceService, NamespaceIAMRoleAuthorizationService, NotificationRegistrationStatusService, PartitionKeyGroupService, PublishingFrequencyService, RecordGroupService, RelationalTableRegistrationService, SearchIndexService, SearchIndexActivationService, SecurityFunctionService, SecurityRoleService, SecurityRoleToFunctionMappingService, StorageService, StoragePlatformService, StoragePolicyService, StorageUnitService, StorageUnitNotificationRegistrationService, SubjectMatterExpertService, SystemJobService, TagService, TagTypeService, UploadAndDownloadService, UserNamespaceAuthorizationService];

var BusinessObjectDataDdl;
(function (BusinessObjectDataDdl) {
    BusinessObjectDataDdl.OutputFormatEnum = {
        HIVE13DDL: 'HIVE_13_DDL'
    };
})(BusinessObjectDataDdl || (BusinessObjectDataDdl = {}));

var BusinessObjectDataDdlRequest;
(function (BusinessObjectDataDdlRequest) {
    BusinessObjectDataDdlRequest.OutputFormatEnum = {
        HIVE13DDL: 'HIVE_13_DDL'
    };
})(BusinessObjectDataDdlRequest || (BusinessObjectDataDdlRequest = {}));

/**
 * herd
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * OpenAPI spec version: 0.216.0-SNAPSHOT
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
var BusinessObjectFormatDdl;
(function (BusinessObjectFormatDdl) {
    BusinessObjectFormatDdl.OutputFormatEnum = {
        HIVE13DDL: 'HIVE_13_DDL'
    };
})(BusinessObjectFormatDdl || (BusinessObjectFormatDdl = {}));

/**
 * herd
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * OpenAPI spec version: 0.216.0-SNAPSHOT
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
var BusinessObjectFormatDdlRequest;
(function (BusinessObjectFormatDdlRequest) {
    BusinessObjectFormatDdlRequest.OutputFormatEnum = {
        HIVE13DDL: 'HIVE_13_DDL'
    };
})(BusinessObjectFormatDdlRequest || (BusinessObjectFormatDdlRequest = {}));

/**
 * herd
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * OpenAPI spec version: 0.216.0-SNAPSHOT
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
var JdbcConnection;
(function (JdbcConnection) {
    JdbcConnection.DatabaseTypeEnum = {
        ORACLE: 'ORACLE',
        POSTGRES: 'POSTGRES',
        REDSHIFT: 'REDSHIFT',
        MYSQL: 'MYSQL'
    };
})(JdbcConnection || (JdbcConnection = {}));

var JdbcStatement;
(function (JdbcStatement) {
    JdbcStatement.TypeEnum = {
        UPDATE: 'UPDATE',
        QUERY: 'QUERY'
    };
    JdbcStatement.StatusEnum = {
        SUCCESS: 'SUCCESS',
        ERROR: 'ERROR',
        SKIPPED: 'SKIPPED'
    };
})(JdbcStatement || (JdbcStatement = {}));

var Job;
(function (Job) {
    Job.StatusEnum = {
        RUNNING: 'RUNNING',
        SUSPENDED: 'SUSPENDED',
        COMPLETED: 'COMPLETED'
    };
})(Job || (Job = {}));

/**
 * herd
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * OpenAPI spec version: 0.216.0-SNAPSHOT
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
var JobSummary;
(function (JobSummary) {
    JobSummary.StatusEnum = {
        RUNNING: 'RUNNING',
        SUSPENDED: 'SUSPENDED',
        COMPLETED: 'COMPLETED'
    };
})(JobSummary || (JobSummary = {}));

/**
 * herd
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * OpenAPI spec version: 0.216.0-SNAPSHOT
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
var JobUpdateRequest;
(function (JobUpdateRequest) {
    JobUpdateRequest.ActionEnum = {
        SUSPEND: 'SUSPEND',
        RESUME: 'RESUME'
    };
})(JobUpdateRequest || (JobUpdateRequest = {}));

/**
 * herd
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * OpenAPI spec version: 0.216.0-SNAPSHOT
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
var NamespaceAuthorization;
(function (NamespaceAuthorization) {
    NamespaceAuthorization.NamespacePermissionsEnum = {
        READ: 'READ',
        WRITE: 'WRITE',
        EXECUTE: 'EXECUTE',
        GRANT: 'GRANT',
        WRITEDESCRIPTIVECONTENT: 'WRITE_DESCRIPTIVE_CONTENT',
        WRITEATTRIBUTE: 'WRITE_ATTRIBUTE'
    };
})(NamespaceAuthorization || (NamespaceAuthorization = {}));

var UserNamespaceAuthorization;
(function (UserNamespaceAuthorization) {
    UserNamespaceAuthorization.NamespacePermissionsEnum = {
        READ: 'READ',
        WRITE: 'WRITE',
        EXECUTE: 'EXECUTE',
        GRANT: 'GRANT',
        WRITEDESCRIPTIVECONTENT: 'WRITE_DESCRIPTIVE_CONTENT',
        WRITEATTRIBUTE: 'WRITE_ATTRIBUTE'
    };
})(UserNamespaceAuthorization || (UserNamespaceAuthorization = {}));

var UserNamespaceAuthorizationCreateRequest;
(function (UserNamespaceAuthorizationCreateRequest) {
    UserNamespaceAuthorizationCreateRequest.NamespacePermissionsEnum = {
        READ: 'READ',
        WRITE: 'WRITE',
        EXECUTE: 'EXECUTE',
        GRANT: 'GRANT',
        WRITEDESCRIPTIVECONTENT: 'WRITE_DESCRIPTIVE_CONTENT',
        WRITEATTRIBUTE: 'WRITE_ATTRIBUTE'
    };
})(UserNamespaceAuthorizationCreateRequest || (UserNamespaceAuthorizationCreateRequest = {}));

/**
 * herd
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * OpenAPI spec version: 0.216.0-SNAPSHOT
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
var UserNamespaceAuthorizationUpdateRequest;
(function (UserNamespaceAuthorizationUpdateRequest) {
    UserNamespaceAuthorizationUpdateRequest.NamespacePermissionsEnum = {
        READ: 'READ',
        WRITE: 'WRITE',
        EXECUTE: 'EXECUTE',
        GRANT: 'GRANT',
        WRITEDESCRIPTIVECONTENT: 'WRITE_DESCRIPTIVE_CONTENT',
        WRITEATTRIBUTE: 'WRITE_ATTRIBUTE'
    };
})(UserNamespaceAuthorizationUpdateRequest || (UserNamespaceAuthorizationUpdateRequest = {}));

var ApiModule = /** @class */ (function () {
    function ApiModule(parentModule, http) {
        if (parentModule) {
            throw new Error('ApiModule is already loaded. Import in your base AppModule only.');
        }
        if (!http) {
            throw new Error('You need to import the HttpClientModule in your AppModule! \n' +
                'See also https://github.com/angular/angular/issues/20575');
        }
    }
    ApiModule_1 = ApiModule;
    ApiModule.forRoot = function (configurationFactory) {
        return {
            ngModule: ApiModule_1,
            providers: [{ provide: Configuration, useFactory: configurationFactory }]
        };
    };
    var ApiModule_1;
    ApiModule = ApiModule_1 = __decorate([
        NgModule({
            imports: [],
            declarations: [],
            exports: [],
            providers: [
                AllowedAttributeValueService,
                ApplicationService,
                AttributeValueListService,
                AvailabilityDayService,
                BusinessObjectDataService,
                BusinessObjectDataAttributeService,
                BusinessObjectDataNotificationRegistrationService,
                BusinessObjectDataStatusService,
                BusinessObjectDataStorageFileService,
                BusinessObjectDataStorageUnitService,
                BusinessObjectDataStorageUnitStatusService,
                BusinessObjectDefinitionService,
                BusinessObjectDefinitionColumnService,
                BusinessObjectDefinitionDescriptionSuggestionService,
                BusinessObjectDefinitionSubjectMatterExpertService,
                BusinessObjectDefinitionTagService,
                BusinessObjectFormatService,
                BusinessObjectFormatExternalInterfaceDescriptiveInformationService,
                BusinessObjectFormatToExternalInterfaceMappingService,
                ConfigurationEntryService,
                CurrentUserService,
                CustomDDLService,
                DataProviderService,
                DepartmentService,
                EMRService,
                EMRClusterDefinitionService,
                ExpectedPartitionValueService,
                ExternalInterfaceService,
                FileTypeService,
                GlobalAttributeDefinitionService,
                IndexSearchService,
                JobService,
                JobDefinitionService,
                NamespaceService,
                NamespaceIAMRoleAuthorizationService,
                NotificationRegistrationStatusService,
                PartitionKeyGroupService,
                PublishingFrequencyService,
                RecordGroupService,
                RelationalTableRegistrationService,
                SearchIndexService,
                SearchIndexActivationService,
                SecurityFunctionService,
                SecurityRoleService,
                SecurityRoleToFunctionMappingService,
                StorageService,
                StoragePlatformService,
                StoragePolicyService,
                StorageUnitService,
                StorageUnitNotificationRegistrationService,
                SubjectMatterExpertService,
                SystemJobService,
                TagService,
                TagTypeService,
                UploadAndDownloadService,
                UserNamespaceAuthorizationService
            ]
        }),
        __param(0, Optional()), __param(0, SkipSelf()),
        __param(1, Optional()),
        __metadata("design:paramtypes", [ApiModule,
            HttpClient])
    ], ApiModule);
    return ApiModule;
}());

/**
 * Generated bundle index. Do not edit.
 */

export { APIS, AllowedAttributeValueService, ApplicationService, AttributeValueListService, AvailabilityDayService, BusinessObjectDataService, BusinessObjectDataAttributeService, BusinessObjectDataNotificationRegistrationService, BusinessObjectDataStatusService, BusinessObjectDataStorageFileService, BusinessObjectDataStorageUnitService, BusinessObjectDataStorageUnitStatusService, BusinessObjectDefinitionService, BusinessObjectDefinitionColumnService, BusinessObjectDefinitionDescriptionSuggestionService, BusinessObjectDefinitionSubjectMatterExpertService, BusinessObjectDefinitionTagService, BusinessObjectFormatService, BusinessObjectFormatExternalInterfaceDescriptiveInformationService, BusinessObjectFormatToExternalInterfaceMappingService, ConfigurationEntryService, CurrentUserService, CustomDDLService, DataProviderService, DepartmentService, EMRService, EMRClusterDefinitionService, ExpectedPartitionValueService, ExternalInterfaceService, FileTypeService, GlobalAttributeDefinitionService, IndexSearchService, JobService, JobDefinitionService, NamespaceService, NamespaceIAMRoleAuthorizationService, NotificationRegistrationStatusService, PartitionKeyGroupService, PublishingFrequencyService, RecordGroupService, RelationalTableRegistrationService, SearchIndexService, SearchIndexActivationService, SecurityFunctionService, SecurityRoleService, SecurityRoleToFunctionMappingService, StorageService, StoragePlatformService, StoragePolicyService, StorageUnitService, StorageUnitNotificationRegistrationService, SubjectMatterExpertService, SystemJobService, TagService, TagTypeService, UploadAndDownloadService, UserNamespaceAuthorizationService, BusinessObjectDataDdl, BusinessObjectDataDdlRequest, BusinessObjectFormatDdl, BusinessObjectFormatDdlRequest, JdbcConnection, JdbcStatement, Job, JobSummary, JobUpdateRequest, NamespaceAuthorization, UserNamespaceAuthorization, UserNamespaceAuthorizationCreateRequest, UserNamespaceAuthorizationUpdateRequest, BASE_PATH, COLLECTION_FORMATS, Configuration, ApiModule };
